####################################################################################

# NOTE: Before the code can be executed, the R working directory *MUST* 
# be set to the directory that contains the folder 'InteractionForests' (for Linux
# systems R can also be excecuted from the directory that contains the folder
# 'InteractionForests'):

# Remove '#' from the line below and replace 'Z:/here/is/my/path/' by the path
# to the directory that contains 'InteractionForests':

# setwd("Z:/here/is/my/path/")

####################################################################################


# Load data.frame "clas_used" containing information on the data sets used by Couronne et al. (2018) that
# were also used for this paper:

load("./InteractionForests/Data/df_bmr.RData")





# Download the data sets from OpenML (the warning "Data set has been deactivated." 
# can be ignored):

library("OpenML")

for(i in 1:nrow(clas_used)) {
  
  dataobj = getOMLDataSet(data.id = clas_used$data.id[i])
  dataset <- dataobj$data
  
  if("Ytarget" %in% names(dataset))
    stop("Name 'Ytarget' already taken")
  
  names(dataset)[names(dataset)==dataobj$target.features] <- "Ytarget"
  
  save(dataset, file=paste("InteractionForests/Data/Datasets/Dataset", i, "_", 
                           dataobj$desc$name, "_id", dataobj$desc$id, ".Rda", sep=""))
  cat(paste("dataset ", i, " of ", nrow(clas_used), sep=""), "\n")
  
}

allids <- as.numeric(sapply(list.files("./InteractionForests/Data/Datasets"), function(x) strsplit(strsplit(x, split="dataset")[[1]][2], split="_")[[1]][1]))
alldatafiles <- list.files("./InteractionForests/Data/Datasets")[order(allids)]




# For some data sets the target variable is of type "logical". --> Convert to "factor":

for(i in seq(along=alldatafiles)) {
  load(paste("./InteractionForests/Data/Datasets/", alldatafiles[i], sep=""))
  
  if(class(dataset$Ytarget)=="logical") {
    dataset$Ytarget <- factor(dataset$Ytarget)
    save(dataset, file=paste("./InteractionForests/Data/Datasets/", alldatafiles[i], sep=""))
  }
  
  if(i %% 10 == 0)
    cat(paste("Iteration:", i), "\n")
}






# There were nine data sets for which random forest with extremely randomized trees did not 
# work, due to specific factor variables contained in these data sets. This lead to the
# R session aborting each time when trying to apply this method to the data sets using 
# the ranger implementation.

# In the following the corresponding factor variables are removed from these data sets.


# Concerning data sets:

baddatasets <- c("dataset113_arsenic-male-bladder_id947.Rda", "dataset115_arsenic-female-lung_id950.Rda", 
                 "dataset116_arsenic-male-lung_id951.Rda", "dataset20_analcatdata_japansolvent_id467.Rda", 
                 "dataset22_analcatdata_bankruptcy_id476.Rda", "dataset57_witmer_census_1980_id787.Rda", 
                 "dataset89_sleuth_case1201_id892.Rda", "dataset95_chscase_adopt_id905.Rda",
                 "dataset114_arsenic-female-bladder_id949.Rda")


all(baddatasets %in% alldatafiles)


i <- 1

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$group <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))



i <- 2

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$group <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))




i <- 3

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$group <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))




i <- 4

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$Firm <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))




i <- 5

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$Company <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))




i <- 6

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$STATE <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))




i <- 7

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$state <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))




i <- 8

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$col_1 <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

    


i <- 9

load(paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))

head(dataset)
dataset$group <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", baddatasets[i], sep=""))








# There were ten further data sets for which random forest with extremely randomized trees also did not 
# work due to specific factor variables contained in these data sets.
# While for these data sets the R session did not abort without an error message, it
# nevertheless ended, this time with a error message.

# In the following the corresponding factor variable are removed from these data sets.


# Concerning data sets:


datasetnames <- c("dataset7_molecular-biology_promoters_id164.Rda", "dataset23_analcatdata_cyyoung9302_id479.Rda", 
                  "dataset43_analcatdata_election2000_id758.Rda", "dataset44_analcatdata_olympic2000_id759.Rda", 
                  "dataset63_chscase_funds_id801.Rda", "dataset78_analcatdata_gviolence_id859.Rda", 
                  "dataset104_humandevel_id924.Rda", "dataset186_spectrometer_id954.Rda", 
                  "dataset120_zoo_id965.Rda", "dataset125_collins_id987.Rda")


i <- 1

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$instance <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 2

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$Pitcher <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 3

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$County <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 4

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$Country <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 5

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$col_1 <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 6

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$Title <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 7

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$country <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 8

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$LRS.name <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 9

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$animal <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))



i <- 10

load(paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))

head(dataset)
dataset$Text <- NULL
head(dataset)

save(dataset, file=paste("./InteractionForests/Data/Datasets/", datasetnames[i], sep=""))









# Make a data.frame containing meta information on the data sets, such as sample size 
# and numbers of covariates (this data.frame will lateron be used in the evaluation of the results):


allids <- as.numeric(sapply(list.files("./InteractionForests/Data/Datasets"), function(x) strsplit(strsplit(x, split="dataset")[[1]][2], split="_")[[1]][1]))
alldatafiles <- list.files("./InteractionForests/Data/Datasets")[order(allids)]

ns <- ps <- cmax <- 0

for(i in seq(along=alldatafiles)) {
  load(paste("./InteractionForests/Data/Datasets/", alldatafiles[i], sep=""))
  ns[i] <- nrow(dataset)
  ps[i] <- ncol(dataset) - 1
  cmax[i] <- max(table(dataset$Ytarget))/sum(table(dataset$Ytarget))
  if(i %% 10 == 0)
    cat(paste("Iteration:", i), "\n")
}

ns2 <- ns[ns <= 10000]
ps2 <- ps[ns <= 10000]
cmax2 <- cmax[ns <= 10000]
datasets2 <- alldatafiles[ns <= 10000]


dataids2 <- sapply(datasets2, function(x) strsplit(strsplit(x, split="_id")[[1]][2], split=".Rda")[[1]][1])
names(dataids2) <- NULL


dataids2[ps2 > 500]
dataidslargep <- c("1042", "1038", "1039", "1176")


inclind <- which(!(dataids2 %in% dataidslargep))


ns2 <- ns2[inclind]
ps2 <- ps2[inclind]
cmax2 <- cmax2[inclind]
datasets2 <- datasets2[inclind]
dataids2 <- dataids2[inclind]

datainfo <- data.frame(dataid=dataids2, n=ns2, p=ps2, cmax=cmax2)


head(datainfo)

save(datainfo, file="./InteractionForests/Data/datainfo.Rda")










# Get the IDs of all data sets with at most 10000 observations
# (these will be used in the analyses - excluding those with more
# than 500 features):

allids <- as.numeric(sapply(list.files("./InteractionForests/Data/Datasets"), function(x) strsplit(strsplit(x, split="dataset")[[1]][2], split="_")[[1]][1]))
alldatafiles <- list.files("./InteractionForests/Data/Datasets")[order(allids)]


idsmaller <- sapply(alldatafiles[ns <= 10000], function(x) strsplit(strsplit(x, split="_id")[[1]][2], split=".Rda")[[1]][1])

cat(paste(idsmaller, collapse="\", \""), "\n")

dataidsmaller10000 <- c("37", "40", "43", "50", "53", "59", "164", "292", "333", "334", 
                        "335", "336", "337", "346", "444", "446", "448", "450", "459", 
                        "467", "472", "476", "479", "682", "683", "713", "714", "717", 
                        "719", "721", "724", "729", "731", "733", "736", "741", "745", 
                        "747", "748", "750", "753", "755", "758", "759", "764", "765", 
                        "767", "770", "771", "772", "774", "777", "778", "780", "782", 
                        "784", "787", "788", "790", "791", "795", "800", "801", "804", 
                        "811", "814", "815", "817", "818", "820", "826", "827", "835", 
                        "841", "848", "853", "857", "859", "860", "872", "874", "875", 
                        "880", "882", "885", "886", "887", "890", "892", "893", "894", 
                        "895", "900", "902", "905", "906", "907", "908", "909", "914", 
                        "915", "919", "921", "924", "925", "927", "928", "929", "931", 
                        "934", "945", "946", "947", "949", "950", "951", "955", "962", 
                        "964", "965", "969", "973", "974", "983", "987", "988", "991", 
                        "994", "997", "1005", "1009", "1011", "1013", "1014", "1015", 
                        "1016", "1025", "1045", "1048", "1054", "1055", "1059", "1060", 
                        "1061", "1062", "1063", "1064", "1065", "1066", "1071", "1073", 
                        "1075", "1121", "1441", "1442", "1446", "1447", "1455", "1462", 
                        "1463", "1464", "1467", "1473", "1480", "1488", "1490", "1495", 
                        "1498", "1510", "1511", "1524", "31", "311", "720", "725", "728", 
                        "737", "803", "807", "816", "819", "847", "851", "923", "954", 
                        "958", "970", "995", "1021", "1049", "1050", "1067", "1068", 
                        "1443", "1444", "1451", "1452", "1453", "1454", "1489", "1494", 
                        "1504", "1547", "1570", "44", "312", "316", "735", "761", "971", 
                        "976", "978", "980", "1020", "1022", "1042", "1043", "1056", "1069", 
                        "1479", "1487", "1038", "1039", "1176")

