####################################################################################

# NOTE: Before the code can be executed, the R working directory *MUST* 
# be set to the directory that contains the folder 'InteractionForests' (for Linux
# systems R can also be excecuted from the directory that contains the folder
# 'InteractionForests'):

# Remove '#' from the line below and replace 'Z:/here/is/my/path/' by the path
# to the directory that contains 'InteractionForests':

# setwd("Z:/here/is/my/path/")

####################################################################################



# Load results:
################

# This part comprised within "if(FALSE){}" does *NOT* 
# have to be executed. This is only needed, when reproducing
# the results from scratch, but not for evaluation.
# The files loaded in this part do not exist prior
# to reproducing the results.
if(FALSE) {
  
  # Determine which iterations of the calculations were
  # successful (all but four were successful):
  donefiles <- list.files("./InteractionForests/Results/LargeStudy_Rda_files/")
  
  inddonefiles <- gsub(".Rda", "", donefiles)
  inddonefiles <- as.numeric(gsub("res_", "", inddonefiles))
  
  reorderind <- order(inddonefiles)
  donefiles <- donefiles[reorderind]
  inddonefiles <- inddonefiles[reorderind]
  
  load("./InteractionForests/Results/scenariogrid_LargeStudy.Rda")  
  scenariogrid$done <- FALSE
  scenariogrid$done[inddonefiles] <- TRUE
  
  sum(!scenariogrid$done)
  table(scenariogrid$done, scenariogrid$method)
  
  
  # Load the results:
  Results <- list()
  for(i in seq(along=donefiles)) {
    load(paste("./InteractionForests/Results/LargeStudy_Rda_files/", donefiles[i], sep=""))
    Results[[i]] <- res
  }
  
  # Save the combined results:
  save(scenariogrid, file="./InteractionForests/Results/scenariogrid_LargeStudy_done.Rda")
  save(Results, file="./InteractionForests/Results/Results_LargeStudy.Rda")
  
}

# Load the results:
load("./InteractionForests/Results/scenariogrid_LargeStudy_done.Rda")
load("./InteractionForests/Results/Results_LargeStudy.Rda")
load("./InteractionForests/Data/datainfo.Rda")





# Pre-process the results:
###########################

results <- scenariogrid
results$auc[results$done] <- sapply(Results, function(x) mean(sapply(x, function(y) y$auctest)))
results$acc[results$done] <- sapply(Results, function(x) mean(sapply(x, function(y) y$acctest)))
results$brier[results$done] <- sapply(Results, function(x) mean(sapply(x, function(y) y$briertest)))

results$n <- sapply(results$dataid, function(x) datainfo$n[datainfo$dataid==x])
results$p <- sapply(results$dataid, function(x) datainfo$p[datainfo$dataid==x])

results$method[results$method=="interactionforest"] <- "IF"
results$method[results$method=="randomforest"] <- "RF"
results$method[results$method=="canonicalforest"] <- "CaF"
results$method[results$method=="obliqueforest"] <- "ObF"
results$method[results$method=="rotationforest"] <- "RoF"

results$method <- factor(results$method, levels=c("IF", "RF", "CaF", "ObF", "RoF"))



orderind <- order(results$dataid, results$cvind, results$method)
results <- results[orderind,]
Results <- Results[orderind]


results$done <- NULL
results$seed <- NULL
results$settingid <- NULL



library("plyr")
resultssum <- ddply(results, .variables=c("dataid", "method", "n", "p"), .fun=summarise, 
                    acc=mean(acc, na.rm=TRUE), auc=mean(auc, na.rm=TRUE), brier=mean(brier, na.rm=TRUE))







# Table: Performances of the methods summarized across the 220 data sets.
##########################################################################

medians <- format(round(tapply(resultssum$auc, resultssum$method, median, na.rm=TRUE), 4), nsmall=4)
QS1 <- format(round(tapply(resultssum$auc, resultssum$method, quantile, probs=0.25, na.rm=TRUE), 4), nsmall=4)
QS3 <- format(round(tapply(resultssum$auc, resultssum$method, quantile, probs=0.75, na.rm=TRUE), 4), nsmall=4)
aucs <- paste(medians, " [", QS1, ", ", QS3, "]", sep="")

medians <- format(round(tapply(resultssum$acc, resultssum$method, median, na.rm=TRUE), 4), nsmall=4)
QS1 <- format(round(tapply(resultssum$acc, resultssum$method, quantile, probs=0.25, na.rm=TRUE), 4), nsmall=4)
QS3 <- format(round(tapply(resultssum$acc, resultssum$method, quantile, probs=0.75, na.rm=TRUE), 4), nsmall=4)
accs <- paste(medians, " [", QS1, ", ", QS3, "]", sep="")

medians <- format(round(tapply(resultssum$brier, resultssum$method, median, na.rm=TRUE), 4), nsmall=4)
QS1 <- format(round(tapply(resultssum$brier, resultssum$method, quantile, probs=0.25, na.rm=TRUE), 4), nsmall=4)
QS3 <- format(round(tapply(resultssum$brier, resultssum$method, quantile, probs=0.75, na.rm=TRUE), 4), nsmall=4)
briers <- paste(medians, " [", QS1, ", ", QS3, "]", sep="")

res <- cbind(names(medians), aucs, accs, briers)
res

restab <- paste(apply(res, 1, paste, collapse= " & "), "\\\\", sep="")
for(i in seq(along=restab))
  cat(restab[i], "\n")


sort(tapply(resultssum$auc, resultssum$method, median, na.rm=TRUE))
sort(tapply(resultssum$acc, resultssum$method, median, na.rm=TRUE))
sort(tapply(resultssum$brier, resultssum$method, median, na.rm=TRUE), decreasing = TRUE)







# Testing for significant differences between the performance of IF and the other methods:
##########################################################################################

library("rstatix")

resultssumtemp <- resultssum[resultssum$method %in% c("IF", "RF"),]
resultssumtemp$method <- factor(as.character(resultssumtemp$method), levels=c("IF", "RF"))

paucs <- c(wilcox.test(resultssum$auc[resultssum$method=="IF"], resultssum$auc[resultssum$method=="RF"], paired=TRUE)$p.value,
           wilcox.test(resultssum$auc[resultssum$method=="IF"], resultssum$auc[resultssum$method=="CaF"], paired=TRUE)$p.value,
           wilcox.test(resultssum$auc[resultssum$method=="IF"], resultssum$auc[resultssum$method=="ObF"], paired=TRUE)$p.value,
           wilcox.test(resultssum$auc[resultssum$method=="IF"], resultssum$auc[resultssum$method=="RoF"], paired=TRUE)$p.value)

raucs <- rep(NA, 4)
datatemp <- resultssum[resultssum$method %in% c("IF", "RF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "RF"))
raucs[1] <- wilcox_effsize(data = datatemp, formula=auc ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "CaF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "CaF"))
raucs[2] <- wilcox_effsize(data = datatemp, formula=auc ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "ObF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "ObF"))
raucs[3] <- wilcox_effsize(data = datatemp, formula=auc ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "RoF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "RoF"))
raucs[4] <- wilcox_effsize(data = datatemp, formula=auc ~ method, paired = TRUE)$effsize
raucs <- round(raucs, 2)

paucsadjust <- p.adjust(paucs, method = "holm")
names(paucsadjust) <- c("RF", "CaF", "ObF", "RoF")
names(raucs) <- c("RF", "CaF", "ObF", "RoF")


paccs <- c(wilcox.test(resultssum$acc[resultssum$method=="IF"], resultssum$acc[resultssum$method=="RF"], paired=TRUE)$p.value,
           wilcox.test(resultssum$acc[resultssum$method=="IF"], resultssum$acc[resultssum$method=="CaF"], paired=TRUE)$p.value,
           wilcox.test(resultssum$acc[resultssum$method=="IF"], resultssum$acc[resultssum$method=="ObF"], paired=TRUE)$p.value,
           wilcox.test(resultssum$acc[resultssum$method=="IF"], resultssum$acc[resultssum$method=="RoF"], paired=TRUE)$p.value)

raccs <- rep(NA, 4)
datatemp <- resultssum[resultssum$method %in% c("IF", "RF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "RF"))
raccs[1] <- wilcox_effsize(data = datatemp, formula=acc ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "CaF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "CaF"))
raccs[2] <- wilcox_effsize(data = datatemp, formula=acc ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "ObF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "ObF"))
raccs[3] <- wilcox_effsize(data = datatemp, formula=acc ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "RoF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "RoF"))
raccs[4] <- wilcox_effsize(data = datatemp, formula=acc ~ method, paired = TRUE)$effsize
raccs <- round(raccs, 2)

paccsadjust <- p.adjust(paccs, method = "holm")
names(paccsadjust) <- c("RF", "CaF", "ObF", "RoF")
names(raccs) <- c("RF", "CaF", "ObF", "RoF")


pbriers <- c(wilcox.test(resultssum$brier[resultssum$method=="IF"], resultssum$brier[resultssum$method=="RF"], paired=TRUE)$p.value,
             wilcox.test(resultssum$brier[resultssum$method=="IF"], resultssum$brier[resultssum$method=="CaF"], paired=TRUE)$p.value,
             wilcox.test(resultssum$brier[resultssum$method=="IF"], resultssum$brier[resultssum$method=="ObF"], paired=TRUE)$p.value,
             wilcox.test(resultssum$brier[resultssum$method=="IF"], resultssum$brier[resultssum$method=="RoF"], paired=TRUE)$p.value)

rbriers <- rep(NA, 4)
datatemp <- resultssum[resultssum$method %in% c("IF", "RF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "RF"))
rbriers[1] <- wilcox_effsize(data = datatemp, formula=brier ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "CaF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "CaF"))
rbriers[2] <- wilcox_effsize(data = datatemp, formula=brier ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "ObF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "ObF"))
rbriers[3] <- wilcox_effsize(data = datatemp, formula=brier ~ method, paired = TRUE)$effsize
datatemp <- resultssum[resultssum$method %in% c("IF", "RoF"),]
datatemp$method <- factor(as.character(datatemp$method), levels=c("IF", "RoF"))
rbriers[4] <- wilcox_effsize(data = datatemp, formula=brier ~ method, paired = TRUE)$effsize
rbriers <- round(rbriers, 2)

pbriersadjust <- p.adjust(pbriers, method = "holm")
names(pbriersadjust) <- c("RF", "CaF", "ObF", "RoF")
names(rbriers) <- c("RF", "CaF", "ObF", "RoF")


paucsadjustsafe <- paucsadjust
paccsadjustsafe <- paccsadjust
pbriersadjustsafe <- pbriersadjust


paucsadjust <- ifelse(paucsadjust < 0.001, "< 0.001", format(round(paucsadjust, 3), nsmall=3))
paccsadjust <- ifelse(paccsadjust < 0.001, "< 0.001", format(round(paccsadjust, 3), nsmall=3))
pbriersadjust <- ifelse(pbriersadjust < 0.001, "< 0.001", format(round(pbriersadjust, 3), nsmall=3))



# p-values:
cat(paste(paste("IF vs.\\ ", names(paucsadjust), ": p =", paucsadjust, sep=""), collapse=", "), "\n")
cat(paste(paste("IF vs.\\ ", names(paccsadjust), ": p =", paccsadjust, sep=""), collapse=", "), "\n")
cat(paste(paste("IF vs.\\ ", names(pbriersadjust), ": p =", pbriersadjust, sep=""), collapse=", "), "\n")


# Effect sizes:
cat(paste(paste("IF vs.\\ ", names(raucs), ": r = ", raucs, sep=""), collapse=", "), "\n")
cat(paste(paste("IF vs.\\ ", names(raccs), ": r = ", raccs, sep=""), collapse=", "), "\n")
cat(paste(paste("IF vs.\\ ", names(rbriers), ": r = ", rbriers, sep=""), collapse=", "), "\n")








# Figure: Ranks of the methods with respect to the different performance metrics.
#################################################################################

aucranks <- t(apply(-cbind(resultssum$auc[resultssum$method=="IF"], resultssum$auc[resultssum$method=="RF"], 
                           resultssum$auc[resultssum$method=="CaF"], resultssum$auc[resultssum$method=="ObF"],
                           resultssum$auc[resultssum$method=="RoF"]), 1, rank))
accranks <- t(apply(-cbind(resultssum$acc[resultssum$method=="IF"], resultssum$acc[resultssum$method=="RF"], 
                           resultssum$acc[resultssum$method=="CaF"], resultssum$acc[resultssum$method=="ObF"],
                           resultssum$acc[resultssum$method=="RoF"]), 1, rank))
brierranks <- t(apply(cbind(resultssum$brier[resultssum$method=="IF"], resultssum$brier[resultssum$method=="RF"], 
                            resultssum$brier[resultssum$method=="CaF"], resultssum$brier[resultssum$method=="ObF"],
                            resultssum$brier[resultssum$method=="RoF"]), 1, rank))

resultssum$accranks <- as.vector(t(accranks))
resultssum$aucranks <- as.vector(t(aucranks))
resultssum$brierranks <- as.vector(t(brierranks))


library("ggplot2")
ggdata <- reshape(resultssum, varying=c("aucranks", "accranks", "brierranks"), 
                  v.names="rank", 
                  timevar="metric", times=c("AUC", "ACC", "Brier"),
                  direction="long")
ggdata$metric <- factor(ggdata$metric, levels=c("AUC", "ACC", "Brier"))

p <- ggplot(data=ggdata, aes(fill=factor(rank), x=method)) + theme_bw() + 
  theme(strip.text.x=element_text(size=11), axis.text.x = element_text(colour = "black", size=11),
        axis.title=element_text(size=11)) +
  labs(x="Method", y="Number of data sets") + scale_fill_discrete(name="Rank") +
  geom_bar(position="stack") + facet_wrap(~metric)
p

ggsave(file="./InteractionForests/Results/Figures/Figure3.pdf", width=8*1.3, height=3.5*1.3)






# Few of the data sets for which CaF performed best with respect to the Brier involved many variables:

boxplot(resultssum$p[resultssum$method=="RF"] ~ as.numeric(resultssum$brierranks[resultssum$method=="CaF"]==1))
quantile(resultssum$p[resultssum$method=="RF"][resultssum$brierranks[resultssum$method=="CaF"]==1], (1:9)/10)
quantile(resultssum$p[resultssum$method=="RF"][resultssum$brierranks[resultssum$method=="CaF"]!=1], (1:9)/10)




# While there are no notable visible indications of an improvement of
# IF over RF in terms of the accuracy in Figure 3, IF featured the best mean rank
# among the methods:

sort(tapply(resultssum$accranks, resultssum$ method, mean))







# Supplementary Figures: Dependencies of the method ranks with respect to the different performance metrics on
# the numbers of variables in the data sets and on their sample sizes.
###############################################################################################################


library("scales")

set.seed(1234)
p <- ggplot(data=ggdata[ggdata$metric=="ACC",], aes(x=p, y=rank)) + theme_bw() + scale_x_continuous(trans='log', breaks=c(2, 5, 10, 20, 50, 100, 200)) + 
  theme(strip.text.x=element_text(size=15), axis.text = element_text(size=13),
        axis.title=element_text(size=15), plot.margin=unit(c(5.5,5.5,5.5,5.5),"points")) + geom_jitter(height=0.3) + geom_smooth(se=TRUE) + facet_wrap(~method, nrow=2) + 
  labs(x="Number of variables", y="Rank")
p

ggsave(file="./InteractionForests/Results/Figures/DependencypACC.pdf", width=9.1*1.3, height=5*1.3)


set.seed(1234)
p <- ggplot(data=ggdata[ggdata$metric=="AUC",], aes(x=p, y=rank)) + theme_bw() + scale_x_continuous(trans='log', breaks=c(2, 5, 10, 20, 50, 100, 200)) + 
  theme(strip.text.x=element_text(size=15), axis.text = element_text(size=13),
        axis.title=element_text(size=15), plot.margin=unit(c(5.5,5.5,5.5,5.5),"points")) + geom_jitter(height=0.3) + geom_smooth(se=TRUE) + facet_wrap(~method, nrow=2) + 
  labs(x="Number of variables", y="Rank")
p

ggsave(file="./InteractionForests/Results/Figures/DependencypAUC.pdf", width=9.1*1.3, height=5*1.3)


set.seed(1234)
p <- ggplot(data=ggdata[ggdata$metric=="Brier",], aes(x=p, y=rank)) + theme_bw() + scale_x_continuous(trans='log', breaks=c(2, 5, 10, 20, 50, 100, 200)) + 
  theme(strip.text.x=element_text(size=15), axis.text = element_text(size=13),
        axis.title=element_text(size=15), plot.margin=unit(c(5.5,5.5,5.5,5.5),"points")) + geom_jitter(height=0.3) + geom_smooth(se=TRUE) + facet_wrap(~method, nrow=2) + 
  labs(x="Number of variables", y="Rank")
p

ggsave(file="./InteractionForests/Results/Figures/DependencypBrier.pdf", width=9.1*1.3, height=5*1.3)





set.seed(1234)
p <- ggplot(data=ggdata[ggdata$metric=="ACC",], aes(x=n, y=rank)) + theme_bw() + scale_x_continuous(trans='log', breaks=c(50, 100, 200, 400, 800, 1500, 3000, 6000, 12000)) + 
  theme(strip.text.x=element_text(size=15), axis.text.x = element_text(size=10), axis.text.y = element_text(size=13),
        axis.title=element_text(size=15), plot.margin=unit(c(5.5,10,5.5,5.5),"points")) + geom_point() + geom_smooth(se=TRUE) + facet_wrap(~method, nrow=2) + coord_cartesian(ylim=c(0.7, 5.3)) +
  labs(x="Sample size", y="Rank")
p

ggsave(file="./InteractionForests/Results/Figures/DependencynACC.pdf", width=9.1*1.3, height=5*1.3)


set.seed(1234)
p <- ggplot(data=ggdata[ggdata$metric=="AUC",], aes(x=n, y=rank)) + theme_bw() + scale_x_continuous(trans='log', breaks=c(50, 100, 200, 400, 800, 1500, 3000, 6000, 12000)) + 
  theme(strip.text.x=element_text(size=15), axis.text.x = element_text(size=10), axis.text.y = element_text(size=13),
        axis.title=element_text(size=15), plot.margin=unit(c(5.5,10,5.5,5.5),"points")) + geom_point() + geom_smooth(se=TRUE) + facet_wrap(~method, nrow=2) + coord_cartesian(ylim=c(0.7, 5.3)) +
  labs(x="Sample size", y="Rank")
p

ggsave(file="./InteractionForests/Results/Figures/DependencynAUC.pdf", width=9.1*1.3, height=5*1.3)


set.seed(1234)
p <- ggplot(data=ggdata[ggdata$metric=="Brier",], aes(x=n, y=rank)) + theme_bw() + scale_x_continuous(trans='log', breaks=c(50, 100, 200, 400, 800, 1500, 3000, 6000, 12000)) + 
  theme(strip.text.x=element_text(size=15), axis.text.x = element_text(size=10), axis.text.y = element_text(size=13),
        axis.title=element_text(size=15), plot.margin=unit(c(5.5,10,5.5,5.5),"points")) + geom_point() + geom_smooth(se=TRUE) + facet_wrap(~method, nrow=2) + coord_cartesian(ylim=c(0.7, 5.3)) +
  labs(x="Sample size", y="Rank")
p

ggsave(file="./InteractionForests/Results/Figures/DependencynBrier.pdf", width=9.1*1.3, height=5*1.3)
