####################################################################################

# NOTE: Before the code can be executed, the R working directory *MUST* 
# be set to the directory that contains the folder 'InteractionForests' (for Linux
# systems R can also be excecuted from the directory that contains the folder
# 'InteractionForests'):

# Remove '#' from the line below and replace 'Z:/here/is/my/path/' by the path
# to the directory that contains 'InteractionForests':

# setwd("Z:/here/is/my/path/")

####################################################################################



# Load results:
################

# This part comprised within "if(FALSE){}" does *NOT* 
# have to be executed. This is only needed, when reproducing
# the results from scratch, but not for evaluation.
# The files loaded in this part do not exist prior
# to reproducing the results.
if(FALSE) {
  
  # Load all results, pre-process and combine them:
  
  load("./InteractionForests/Results/scenariogrid_Simulation_100.Rda")
  load("./InteractionForests/Results/Results_Simulation_100.Rda")
  
  scenariogrid100 <- scenariogrid
  Results100 <- Results
  
  
  load("./InteractionForests/Results/scenariogrid_Simulation_500.Rda")
  load("./InteractionForests/Results/Results_Simulation_500.Rda")
  
  scenariogrid500 <- scenariogrid
  Results500 <- Results
  
  
  load("./InteractionForests/Results/scenariogrid_Simulation_subtree_100_500.Rda")
  load("./InteractionForests/Results/Results_Simulation_subtree_100_500.Rda")
  
  scenariogrid100500subtree <- scenariogrid
  Results100500subtree <- Results
  
  
  load("./InteractionForests/Results/scenariogrid_Simulation_1000.Rda")
  load("./InteractionForests/Results/Results_Simulation_1000.Rda")
  
  scenariogrid1000 <- scenariogrid
  Results1000 <- Results
  
  
  
  scenariogrid100500 <- rbind(scenariogrid100, scenariogrid500)
  Results100500 <- c(Results100, Results500)
  
  orderind <- order(scenariogrid100500$settingid)
  scenariogrid100500 <- scenariogrid100500[orderind,]
  Results100500 <- Results100500[orderind]
  
  orderind <- order(scenariogrid100500subtree$settingid)
  scenariogrid100500subtree <- scenariogrid100500subtree[orderind,]
  Results100500subtree <- Results100500subtree[orderind]
  
  sum(scenariogrid100500$settingid==scenariogrid100500subtree$settingid)
  
  for(i in seq(along=Results100500))
    Results100500[[i]]$SRCsubtree.biv <- Results100500subtree[[i]]$SRCsubtree.biv
  
  
  scenariogrid <- rbind(scenariogrid100500, scenariogrid1000)
  Results <- c(Results100500, Results1000)
  
  
  orderind <- order(scenariogrid$n, scenariogrid$itind)
  scenariogrid <- scenariogrid[orderind,]
  Results <- Results[orderind]
  
  
  for(i in seq(along=Results))
    names(Results[[i]]$iRF.biv) <- sapply(names(Results[[i]]$iRF.biv), function(x) paste(sort(strsplit(x, split="_")[[1]]), collapse=" AND "))
  
  
  # Save the combined results:
  
  save(scenariogrid, file = "./InteractionForests/Results/scenariogrid_Simulation.Rda")
  save(Results, file = "./InteractionForests/Results/Results_Simulation.Rda")
  
}

# Load the results:
load("./InteractionForests/Results/scenariogrid_Simulation.Rda")
load("./InteractionForests/Results/Results_Simulation.Rda")





######################################################################
# NOTE: The labels of the variables are different than those given in the paper:
# In the paper the first 18 variables are those with effect and
# the remaining 50 variables are the noise variables.
# In contrast, here, the first 50 variables are the noise variables
# and the remaining 18 variables are those with effect.
# For example, the variable with label X_1 (X_5) in the paper is variable
# X51 (X55) in the code.
#####################################################################






# Calculate the ranks the variables / variable pairs achieved using 
# the different methods:
####################################################################

set.seed(1234)
results <- scenariogrid
results$seed <- results$settingid <- NULL

resultssafe <- results
results <- rbind(results, results, results, results, results)

results$method <- factor(rep(c("IF", "RF", "PA", "IMDMS", "iRF"), each=nrow(resultssafe)), levels=c("IF", "RF", "PA", "IMDMS", "iRF"))


results <- results[order(results$n, results$itind, results$method),]

results$X51 <- results$X52 <- results$X53 <- results$X54 <- results$X55 <- results$X56 <- results$X57X58quant <-
  results$X57X58qual <- results$X59X60quant <- results$X59X60qual <- results$X61X62quant <- results$X61X62qual <-
  results$X63X64qual <- results$X63X64quant <- results$X65X66qual <- results$X65X66quant <- results$X67X68qual <- 
  results$X67X68quant <- NA



# univariable effects:

univpos <- function(vec, x) {
  # Rank the variables and split ties randomly:
  which(names(vec[order(vec, rnorm(length(vec)), decreasing=TRUE)])==x)
}

results$X51[results$method=="IF"] <- sapply(Results, function(x) univpos(x$eim.univ, "X51"))
results$X51[results$method=="RF"] <- sapply(Results, function(x) univpos(x$variable.importance, "X51"))

results$X52[results$method=="IF"] <- sapply(Results, function(x) univpos(x$eim.univ, "X52"))
results$X52[results$method=="RF"] <- sapply(Results, function(x) univpos(x$variable.importance, "X52"))

results$X53[results$method=="IF"] <- sapply(Results, function(x) univpos(x$eim.univ, "X53"))
results$X53[results$method=="RF"] <- sapply(Results, function(x) univpos(x$variable.importance, "X53"))

results$X54[results$method=="IF"] <- sapply(Results, function(x) univpos(x$eim.univ, "X54"))
results$X54[results$method=="RF"] <- sapply(Results, function(x) univpos(x$variable.importance, "X54"))

results$X55[results$method=="IF"] <- sapply(Results, function(x) univpos(x$eim.univ, "X55"))
results$X55[results$method=="RF"] <- sapply(Results, function(x) univpos(x$variable.importance, "X55"))

results$X56[results$method=="IF"] <- sapply(Results, function(x) univpos(x$eim.univ, "X56"))
results$X56[results$method=="RF"] <- sapply(Results, function(x) univpos(x$variable.importance, "X56"))





# quantitative interaction effects:

bivpos <- function(vec, x) {
  names(vec) <- gsub(" large", "", names(vec))
  names(vec) <- gsub(" small", "", names(vec))
  which(names(vec[order(vec, rnorm(length(vec)), decreasing=TRUE)])==x)
}

bivposPA <- function(vec, x) {
  which(names(vec[order(abs(vec), rnorm(length(vec)), decreasing = TRUE)])==x)
}

bivposIMDMS <- function(vec, x) {
  which(names(vec[order(vec, rnorm(length(vec)))])==x)
}

bivposiRF <- function(vec, x) {
  vec2 <- vec[order(vec, rnorm(length(vec)), decreasing=TRUE)]
  x2 <- strsplit(x, split = " AND ")[[1]]
  posi <- intersect(grep(x2[1], names(vec2)), grep(x2[2], names(vec2)))
  if(length(posi) > 0) {
    return(min(posi))
  } else {
    return(NA)
  }
}

results$X57X58quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X57 AND X58"))
results$X57X58quant[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X57 AND X58"))
results$X57X58quant[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X57 AND X58"))
results$X57X58quant[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X57 AND X58"))
results$X57X58quant[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X57 AND X58"))

results$X59X60quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X59 AND X60"))
results$X59X60quant[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X59 AND X60"))
results$X59X60quant[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X59 AND X60"))
results$X59X60quant[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X59 AND X60"))
results$X59X60quant[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X59 AND X60"))

results$X61X62quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X61 AND X62"))
results$X61X62quant[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X61 AND X62"))
results$X61X62quant[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X61 AND X62"))
results$X61X62quant[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X61 AND X62"))
results$X61X62quant[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X61 AND X62"))




results$X57X58qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X57 AND X58"))
results$X57X58qual[results$method=="RF"] <- results$X57X58quant[results$method=="RF"]
results$X57X58qual[results$method=="PA"] <- results$X57X58quant[results$method=="PA"]
results$X57X58qual[results$method=="IMDMS"] <- results$X57X58quant[results$method=="IMDMS"]
results$X57X58qual[results$method=="iRF"] <- results$X57X58quant[results$method=="iRF"]

results$X59X60qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X59 AND X60"))
results$X59X60qual[results$method=="RF"] <- results$X59X60quant[results$method=="RF"]
results$X59X60qual[results$method=="PA"] <- results$X59X60quant[results$method=="PA"]
results$X59X60qual[results$method=="IMDMS"] <- results$X59X60quant[results$method=="IMDMS"]
results$X59X60qual[results$method=="iRF"] <- results$X59X60quant[results$method=="iRF"]

results$X61X62qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X61 AND X62"))
results$X61X62qual[results$method=="RF"] <- results$X61X62quant[results$method=="RF"]
results$X61X62qual[results$method=="PA"] <- results$X61X62quant[results$method=="PA"]
results$X61X62qual[results$method=="IMDMS"] <- results$X61X62quant[results$method=="IMDMS"]
results$X61X62qual[results$method=="iRF"] <- results$X61X62quant[results$method=="iRF"]




# qualitative interaction effects:

results$X63X64qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X63 AND X64"))
results$X63X64qual[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X63 AND X64"))
results$X63X64qual[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X63 AND X64"))
results$X63X64qual[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X63 AND X64"))
results$X63X64qual[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X63 AND X64"))

results$X65X66qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X65 AND X66"))
results$X65X66qual[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X65 AND X66"))
results$X65X66qual[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X65 AND X66"))
results$X65X66qual[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X65 AND X66"))
results$X65X66qual[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X65 AND X66"))

results$X67X68qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X67 AND X68"))
results$X67X68qual[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X67 AND X68"))
results$X67X68qual[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X67 AND X68"))
results$X67X68qual[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X67 AND X68"))
results$X67X68qual[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X67 AND X68"))




results$X63X64quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X63 AND X64"))
results$X63X64quant[results$method=="RF"] <- results$X63X64qual[results$method=="RF"]
results$X63X64quant[results$method=="PA"] <- results$X63X64qual[results$method=="PA"]
results$X63X64quant[results$method=="IMDMS"] <- results$X63X64qual[results$method=="IMDMS"]
results$X63X64quant[results$method=="iRF"] <- results$X63X64qual[results$method=="iRF"]

results$X65X66quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X65 AND X66"))
results$X65X66quant[results$method=="RF"] <- results$X65X66qual[results$method=="RF"]
results$X65X66quant[results$method=="PA"] <- results$X65X66qual[results$method=="PA"]
results$X65X66quant[results$method=="IMDMS"] <- results$X65X66qual[results$method=="IMDMS"]
results$X65X66quant[results$method=="iRF"] <- results$X65X66qual[results$method=="iRF"]

results$X67X68quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X67 AND X68"))
results$X67X68quant[results$method=="RF"] <- results$X67X68qual[results$method=="RF"]
results$X67X68quant[results$method=="PA"] <- results$X67X68qual[results$method=="PA"]
results$X67X68quant[results$method=="IMDMS"] <- results$X67X68qual[results$method=="IMDMS"]
results$X67X68quant[results$method=="iRF"] <- results$X67X68qual[results$method=="iRF"]






# ranks variable pairs with only main effects, but no interaction effects, obtained for 
# the quantitative and qualitative:


results$X51X52quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X51 AND X52"))
results$X51X52quant[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X51 AND X52"))
results$X51X52quant[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X51 AND X52"))
results$X51X52quant[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X51 AND X52"))
results$X51X52quant[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X51 AND X52"))

results$X53X54quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X53 AND X54"))
results$X53X54quant[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X53 AND X54"))
results$X53X54quant[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X53 AND X54"))
results$X53X54quant[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X53 AND X54"))
results$X53X54quant[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X53 AND X54"))

results$X55X56quant[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.quant, "X55 AND X56"))
results$X55X56quant[results$method=="RF"] <- sapply(Results, function(x) bivpos(x$variable.importance.biv, "X55 AND X56"))
results$X55X56quant[results$method=="PA"] <- sapply(Results, function(x) bivposPA(x$SRC.biv, "X55 AND X56"))
results$X55X56quant[results$method=="IMDMS"] <- sapply(Results, function(x) bivposIMDMS(x$SRCsubtree.biv, "X55 AND X56"))
results$X55X56quant[results$method=="iRF"] <- sapply(Results, function(x) bivposiRF(x$iRF.biv, "X55 AND X56"))



results$X51X52qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X51 AND X52"))
results$X51X52qual[results$method=="RF"] <- results$X51X52quant[results$method=="RF"]
results$X51X52qual[results$method=="PA"] <- results$X51X52quant[results$method=="PA"]
results$X51X52qual[results$method=="IMDMS"] <- results$X51X52quant[results$method=="IMDMS"]
results$X51X52qual[results$method=="iRF"] <- results$X51X52quant[results$method=="iRF"]

results$X53X54qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X53 AND X54"))
results$X53X54qual[results$method=="RF"] <- results$X53X54quant[results$method=="RF"]
results$X53X54qual[results$method=="PA"] <- results$X53X54quant[results$method=="PA"]
results$X53X54qual[results$method=="IMDMS"] <- results$X53X54quant[results$method=="IMDMS"]
results$X53X54qual[results$method=="iRF"] <- results$X53X54quant[results$method=="iRF"]

results$X55X56qual[results$method=="IF"] <- sapply(Results, function(x) bivpos(x$eim.qual, "X55 AND X56"))
results$X55X56qual[results$method=="RF"] <- results$X55X56quant[results$method=="RF"]
results$X55X56qual[results$method=="PA"] <- results$X55X56quant[results$method=="PA"]
results$X55X56qual[results$method=="IMDMS"] <- results$X55X56quant[results$method=="IMDMS"]
results$X55X56qual[results$method=="iRF"] <- results$X55X56quant[results$method=="iRF"]







# Calculate the quartiles of the ranks (including the medians):
###############################################################

library("plyr")

eval(parse(text=paste("resultsmedian <- ddply(results, .variables=c(\"n\", \"method\"), .fun=summarise,", paste(paste(names(results)[-c(1:3)], " = format(round(median(", names(results)[-c(1:3)], ", na.rm=TRUE), 1), nsmall=1)", sep=""), collapse=", "), ")", sep="")))
eval(parse(text=paste("resultsIQR <- ddply(results, .variables=c(\"n\", \"method\"), .fun=summarise,", paste(paste(names(results)[-c(1:3)], " = diff(quantile(", names(results)[-c(1:3)], ", c(0.25, 0.75), na.rm=TRUE))", sep=""), collapse=", "), ")", sep="")))
eval(parse(text=paste("resultsQ25 <- ddply(results, .variables=c(\"n\", \"method\"), .fun=summarise,", paste(paste(names(results)[-c(1:3)], " = format(round(quantile(", names(results)[-c(1:3)], ", 0.25, na.rm=TRUE), 1), nsmall=1)", sep=""), collapse=", "), ")", sep="")))
eval(parse(text=paste("resultsQ75 <- ddply(results, .variables=c(\"n\", \"method\"), .fun=summarise,", paste(paste(names(results)[-c(1:3)], " = format(round(quantile(", names(results)[-c(1:3)], ", 0.75, na.rm=TRUE), 1), nsmall=1)", sep=""), collapse=", "), ")", sep="")))







# Even though the variables with the strongest main  effect X51 and X52 received a median rank of two for both methods,
# these variables received the best rank more often than the second-best rank for all sample
# size scenarios:
#########################################################################################################################


sum(c(results$X51[results$method=="IF" & results$n==100], results$X52[results$method=="IF" & results$n==100])==1)
sum(c(results$X51[results$method=="IF" & results$n==100], results$X52[results$method=="IF" & results$n==100])==2)

sum(c(results$X51[results$method=="IF" & results$n==500], results$X52[results$method=="IF" & results$n==500])==1)
sum(c(results$X51[results$method=="IF" & results$n==500], results$X52[results$method=="IF" & results$n==500])==2)

sum(c(results$X51[results$method=="IF" & results$n==1000], results$X52[results$method=="IF" & results$n==1000])==1)
sum(c(results$X51[results$method=="IF" & results$n==1000], results$X52[results$method=="IF" & results$n==1000])==2)



sum(c(results$X51[results$method=="RF" & results$n==100], results$X52[results$method=="RF" & results$n==100])==1)
sum(c(results$X51[results$method=="RF" & results$n==100], results$X52[results$method=="RF" & results$n==100])==2)

sum(c(results$X51[results$method=="RF" & results$n==500], results$X52[results$method=="RF" & results$n==500])==1)
sum(c(results$X51[results$method=="RF" & results$n==500], results$X52[results$method=="RF" & results$n==500])==2)

sum(c(results$X51[results$method=="RF" & results$n==1000], results$X52[results$method=="RF" & results$n==1000])==1)
sum(c(results$X51[results$method=="RF" & results$n==1000], results$X52[results$method=="RF" & results$n==1000])==2)









# Table: Univariable effects:
#############################


median(c(results$X51[results$n==100 & results$method=="IF"], results$X52[results$n==100 & results$method=="IF"]))
quantile(c(results$X51[results$n==100 & results$method=="IF"], results$X52[results$n==100 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X51[results$n==100 & results$method=="RF"], results$X52[results$n==100 & results$method=="RF"]))
quantile(c(results$X51[results$n==100 & results$method=="RF"], results$X52[results$n==100 & results$method=="RF"]), c(0.25, 0.75))


median(c(results$X53[results$n==100 & results$method=="IF"], results$X54[results$n==100 & results$method=="IF"]))
quantile(c(results$X53[results$n==100 & results$method=="IF"], results$X54[results$n==100 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X53[results$n==100 & results$method=="RF"], results$X54[results$n==100 & results$method=="RF"]))
quantile(c(results$X53[results$n==100 & results$method=="RF"], results$X54[results$n==100 & results$method=="RF"]), c(0.25, 0.75))


median(c(results$X55[results$n==100 & results$method=="IF"], results$X56[results$n==100 & results$method=="IF"]))
quantile(c(results$X55[results$n==100 & results$method=="IF"], results$X56[results$n==100 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X55[results$n==100 & results$method=="RF"], results$X56[results$n==100 & results$method=="RF"]))
quantile(c(results$X55[results$n==100 & results$method=="RF"], results$X56[results$n==100 & results$method=="RF"]), c(0.25, 0.75))





median(c(results$X51[results$n==500 & results$method=="IF"], results$X52[results$n==500 & results$method=="IF"]))
quantile(c(results$X51[results$n==500 & results$method=="IF"], results$X52[results$n==500 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X51[results$n==500 & results$method=="RF"], results$X52[results$n==500 & results$method=="RF"]))
quantile(c(results$X51[results$n==500 & results$method=="RF"], results$X52[results$n==500 & results$method=="RF"]), c(0.25, 0.75))


median(c(results$X53[results$n==500 & results$method=="IF"], results$X54[results$n==500 & results$method=="IF"]))
quantile(c(results$X53[results$n==500 & results$method=="IF"], results$X54[results$n==500 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X53[results$n==500 & results$method=="RF"], results$X54[results$n==500 & results$method=="RF"]))
quantile(c(results$X53[results$n==500 & results$method=="RF"], results$X54[results$n==500 & results$method=="RF"]), c(0.25, 0.75))


median(c(results$X55[results$n==500 & results$method=="IF"], results$X56[results$n==500 & results$method=="IF"]))
quantile(c(results$X55[results$n==500 & results$method=="IF"], results$X56[results$n==500 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X55[results$n==500 & results$method=="RF"], results$X56[results$n==500 & results$method=="RF"]))
quantile(c(results$X55[results$n==500 & results$method=="RF"], results$X56[results$n==500 & results$method=="RF"]), c(0.25, 0.75))






median(c(results$X51[results$n==1000 & results$method=="IF"], results$X52[results$n==1000 & results$method=="IF"]))
quantile(c(results$X51[results$n==1000 & results$method=="IF"], results$X52[results$n==1000 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X51[results$n==1000 & results$method=="RF"], results$X52[results$n==1000 & results$method=="RF"]))
quantile(c(results$X51[results$n==1000 & results$method=="RF"], results$X52[results$n==1000 & results$method=="RF"]), c(0.25, 0.75))


median(c(results$X53[results$n==1000 & results$method=="IF"], results$X54[results$n==1000 & results$method=="IF"]))
quantile(c(results$X53[results$n==1000 & results$method=="IF"], results$X54[results$n==1000 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X53[results$n==1000 & results$method=="RF"], results$X54[results$n==1000 & results$method=="RF"]))
quantile(c(results$X53[results$n==1000 & results$method=="RF"], results$X54[results$n==1000 & results$method=="RF"]), c(0.25, 0.75))


median(c(results$X55[results$n==1000 & results$method=="IF"], results$X56[results$n==1000 & results$method=="IF"]))
quantile(c(results$X55[results$n==1000 & results$method=="IF"], results$X56[results$n==1000 & results$method=="IF"]), c(0.25, 0.75))

median(c(results$X55[results$n==1000 & results$method=="RF"], results$X56[results$n==1000 & results$method=="RF"]))
quantile(c(results$X55[results$n==1000 & results$method=="RF"], results$X56[results$n==1000 & results$method=="RF"]), c(0.25, 0.75))









# Tables: quantitative interaction effects and qualitative interaction effects:
###############################################################################


resultssub <- resultsmedian
resultssub$X57X58qual <- resultssub$X59X60qual <- resultssub$X61X62qual <- resultssub$X63X64quant <- resultssub$X65X66quant <- resultssub$X67X68quant <- 
  resultssub$X51 <- resultssub$X52 <- resultssub$X53 <- resultssub$X54 <- resultssub$X55 <- resultssub$X56 <- 
  resultssub$X51X52quant <- resultssub$X53X54quant <- resultssub$X55X56quant <- resultssub$X51X52qual <- resultssub$X53X54qual <- resultssub$X55X56qual <- NULL

results1 <- resultssub
namestemp <- names(results1)[-c(1:2)]
for(i in seq(along=namestemp)) {
  results1[,namestemp[i]] <- paste(results1[,namestemp[i]], " [", resultsQ25[,namestemp[i]], ", ", resultsQ75[,namestemp[i]], "]", sep="")
}

results1 <- results1[,c(1:2, ncol(results1):3)]


# Quantitative interaction effect:

results11 <- results1[,1:5]
results12 <- results1[,c(1:2, 6:8)]

tabcontent <- apply(results11, 1, function(x) paste(paste(x[-1], collapse=" & "), " \\\\", sep=""))
names(tabcontent) <- NULL
tabcontent <- gsub("NA", "--", tabcontent)

for(i in seq(along=tabcontent))
  cat(tabcontent[i], "\n")



# Qualitative interaction effects:

tabcontent <- apply(results12, 1, function(x) paste(paste(x[-1], collapse=" & "), " \\\\", sep=""))
names(tabcontent) <- NULL
tabcontent <- gsub("NA", "--", tabcontent)

for(i in seq(along=tabcontent))
  cat(tabcontent[i], "\n")








# Frequencies with which iRF selected the variable pairs of interest:
####################################################################

eval(parse(text=paste("resultspropseliRF <- ddply(results[results$method==\"iRF\",1:(ncol(results)-12)], .variables=\"n\", .fun=summarise,", paste(paste(names(results)[4:(ncol(results)-12)], " = mean(!is.na(", names(results)[4:(ncol(results)-12)], "))", sep=""), collapse=", "), ")", sep="")))
resultspropseliRF <- resultspropseliRF[,c(1,ncol(resultspropseliRF):2)]
resultspropseliRF <- resultspropseliRF[,c(1,seq(2, ncol(resultspropseliRF), by=2))]
resultspropseliRFquant <- resultspropseliRF[,c(1,2:4)]
resultspropseliRFqual <- resultspropseliRF[,c(1,5:7)]

eval(parse(text=paste("resultspropseliRFmain <- ddply(results[results$method==\"iRF\",c(1:3, ncol(results)-(2:0))], .variables=\"n\", .fun=summarise,", paste(paste(names(results)[ncol(results)-(2:0)], " = mean(!is.na(", names(results)[ncol(results)-(2:0)], "))", sep=""), collapse=", "), ")", sep="")))


eval(parse(text=paste("resultssumseliRF <- ddply(results[results$method==\"iRF\",1:(ncol(results)-12)], .variables=\"n\", .fun=summarise,", paste(paste(names(results)[4:(ncol(results)-12)], " = sum(!is.na(", names(results)[4:(ncol(results)-12)], "))", sep=""), collapse=", "), ")", sep="")))
resultssumseliRF <- resultssumseliRF[,c(1,ncol(resultssumseliRF):2)]
resultssumseliRF <- resultssumseliRF[,c(1,seq(2, ncol(resultssumseliRF), by=2))]
resultssumseliRFquant <- resultssumseliRF[,c(1,2:4)]
resultssumseliRFqual <- resultssumseliRF[,c(1,5:7)]

eval(parse(text=paste("resultssumseliRFmain <- ddply(results[results$method==\"iRF\",c(1:3, ncol(results)-(2:0))], .variables=\"n\", .fun=summarise,", paste(paste(names(results)[ncol(results)-(2:0)], " = sum(!is.na(", names(results)[ncol(results)-(2:0)], "))", sep=""), collapse=", "), ")", sep="")))


# Quantitative interaction effects:

resultspropseliRFquant
resultssumseliRFquant

for(i in 2:4)
  resultspropseliRFquant[,i] <- paste("(", round(resultspropseliRFquant[,i]*100), "\\%)", sep="")
for(i in 1:3)
  cat(unlist(resultspropseliRFquant[i,]), "\n")



# Qualitative interaction effects:

resultspropseliRFqual
resultssumseliRFqual

for(i in 2:4)
  resultspropseliRFqual[,i] <- paste("(", round(resultspropseliRFqual[,i]*100), "\\%)", sep="")
for(i in 1:3)
  cat(unlist(resultspropseliRFqual[i,]), "\n")



# Variable pairs with main effects only:

resultspropseliRFmain
resultssumseliRFmain

for(i in 2:4)
  resultspropseliRFmain[,i] <- paste("(", round(resultspropseliRFmain[,i]*100), "\\%)", sep="")
for(i in 1:3)
  cat(unlist(resultspropseliRFmain[i,]), "\n")









# Table: specificity of the qualitative and quantitative EIM:
#############################################################

resultssub <- resultsmedian
resultssub$X51 <- resultssub$X52 <- resultssub$X53 <- resultssub$X54 <- resultssub$X55 <- resultssub$X56 <- resultssub$X57X58quant <- 
  resultssub$X59X60quant <- resultssub$X61X62quant <- resultssub$X63X64qual <- resultssub$X65X66qual <- resultssub$X67X68qual <- NULL

results2 <- resultssub
namestemp <- names(results2)[-c(1:2)]
for(i in seq(along=namestemp)) {
  results2[,namestemp[i]] <- paste(results2[,namestemp[i]], " [", resultsQ25[,namestemp[i]], ", ", resultsQ75[,namestemp[i]], "]", sep="")
}

results22 <- data.frame(t(results2[results2$method=="IF",]))
results22 <- results22[-(1:2),]
results22 <- results22[c(6:1, 10:12, 7:9),]
names(results22) <- c("n = 100", "n = 500", "n = 1000")

tabcontent <- apply(results22, 1, function(x) paste("& ", paste(x, collapse=" & "), " \\\\", sep=""))
names(tabcontent) <- NULL

results22

for(i in seq(along=tabcontent))
  cat(tabcontent[i], "\n")









# Supplementary Table: median ranks obtained for variable pairs with main effects, but without interaction effects:
###################################################################################################################

resultssub <- resultsmedian
resultssub$X57X58qual <- resultssub$X59X60qual <- resultssub$X61X62qual <- resultssub$X63X64quant <- resultssub$X65X66quant <- resultssub$X67X68quant <- 
  resultssub$X51 <- resultssub$X52 <- resultssub$X53 <- resultssub$X54 <- resultssub$X55 <- resultssub$X56 <- 
  resultssub$X67X68qual <- resultssub$X65X66qual <- resultssub$X63X64qual <- resultssub$X61X62quant <- resultssub$X59X60quant <- resultssub$X57X58quant <- NULL

results1 <- resultssub
namestemp <- names(results1)[-c(1:2)]
for(i in seq(along=namestemp)) {
  results1[,namestemp[i]] <- paste(results1[,namestemp[i]], " [", resultsQ25[,namestemp[i]], ", ", resultsQ75[,namestemp[i]], "]", sep="")
}


restemp1 <- results1
restemp1$X51X52qual <- restemp1$X53X54qual <- restemp1$X55X56qual <- NULL


restemp2 <- results1
restemp2$X51X52quant <- restemp2$X53X54quant <- restemp2$X55X56quant <- NULL

names(restemp2)[-(1:2)] <- c("X51X52quant", "X53X54quant", "X55X56quant")


results2 <- rbind(restemp2[1,], restemp1[1:5,], restemp2[6,], restemp1[6:10,], restemp2[11,], restemp1[11:15,])


results2

tabcontent <- apply(results2, 1, function(x) paste(paste(x[-(1:2)], collapse=" & "), " \\\\", sep=""))
names(tabcontent) <- NULL
tabcontent <- gsub("NA", "--", tabcontent)

for(i in seq(along=tabcontent))
  cat(tabcontent[i], "\n")










# Supplementary Figure: EIM values of univariable effects.
###########################################################

resultstemp <- results
resultstemp$itind <- NULL


resultstemp2 <- reshape(resultstemp, varying=names(resultstemp)[-c(1:2)], 
                                  v.names="position", 
                                  timevar="effect", times=names(resultstemp)[-c(1:2)],
                                  direction="long")
resultstemp2$n <- paste("n = ", resultstemp2$n, sep="")

resultstemp2$effect[resultstemp2$effect=="X51"] <- "Strong univ. 1"
resultstemp2$effect[resultstemp2$effect=="X52"] <- "Strong univ. 2"
resultstemp2$effect[resultstemp2$effect=="X53"] <- "Moderate univ. 1"
resultstemp2$effect[resultstemp2$effect=="X54"] <- "Moderate univ. 2"
resultstemp2$effect[resultstemp2$effect=="X55"] <- "Weak univ. 1"
resultstemp2$effect[resultstemp2$effect=="X56"] <- "Weak univ. 2"

resultstemp2$n <- factor(resultstemp2$n, levels=c("n = 100", "n = 500", "n = 1000"))




library("ggplot2")
library("scales")

resultsplot <- resultstemp2[resultstemp2$effect %in% c("Strong univ. 1", "Moderate univ. 1", "Weak univ. 1"),]
resultsplot$effect[resultsplot$effect=="Strong univ. 1"] <- "Strong effect"
resultsplot$effect[resultsplot$effect=="Moderate univ. 1"] <- "Moderate effect"
resultsplot$effect[resultsplot$effect=="Weak univ. 1"] <- "Weak effect"

resultsplot$effect <- factor(resultsplot$effect, levels=c("Strong effect", "Moderate effect", "Weak effect"))



resultsplot <- resultsplot[resultsplot$method %in% c("IF", "RF"),]
levels(resultsplot$method) <- c("IF-EIM-univ", "RF-V", "PA", "IMDMS", "iRF") 

p <- ggplot(data=resultsplot, aes(x=method, y=position)) + theme_bw() + facet_wrap(~ n + effect, ncol=3) + 
  theme(strip.text.x=element_text(size=14), axis.text.x = element_text(angle=45, hjust = 1, color="black", size=13),
        axis.text.y = element_text(size=13), axis.title=element_text(size=15)) + labs(x="Method", y="Rank") +
  scale_y_continuous(trans='log', breaks=trans_breaks('log', exp), labels = function(x) round(x)) + geom_boxplot()
p

ggsave(file="./InteractionForests/Results/Figures/SimulationUnivariable.pdf", width=8, height=10.5)








# Supplementary Figure: EIM values of quantitative interaction effects.
#######################################################################

resultstemp2safe <- resultstemp2

resultstemp2$effect[resultstemp2$effect=="X57X58quant"] <- "Strong quant. int."
resultstemp2$effect[resultstemp2$effect=="X59X60quant"] <- "Moderate quant. int."
resultstemp2$effect[resultstemp2$effect=="X61X62quant"] <- "Weak quant. int."
resultstemp2$effect[resultstemp2$effect=="X63X64qual"] <- "Strong qual. int."
resultstemp2$effect[resultstemp2$effect=="X65X66qual"] <- "Moderate qual. int."
resultstemp2$effect[resultstemp2$effect=="X67X68qual"] <- "Weak qual. int."

resultsplot <- resultstemp2[resultstemp2$effect %in% c("Strong quant. int.", "Moderate quant. int.", "Weak quant. int."),]
resultsplot$effect[resultsplot$effect=="Strong quant. int."] <- "Strong effect"
resultsplot$effect[resultsplot$effect=="Moderate quant. int."] <- "Moderate effect"
resultsplot$effect[resultsplot$effect=="Weak quant. int."] <- "Weak effect"
resultsplot$effect <- factor(resultsplot$effect, levels=c("Strong effect", "Moderate effect", "Weak effect"))

levels(resultsplot$method) <- c("IF-EIM-quant", "RF-V-pairs", "PA", "IMDMS", "iRF") 

p <- ggplot(data=resultsplot, aes(x=method, y=position)) + theme_bw() + facet_wrap(~ n + effect, scales="free_y", ncol=3) + labs(x="Method", y="Rank") +
  theme(strip.text.x=element_text(size=14), axis.text.x = element_text(angle=45, hjust = 1, color="black", size=13),
        axis.text.y = element_text(size=13), axis.title=element_text(size=15)) + scale_y_continuous(trans='log', breaks=trans_breaks('log', exp), labels = function(x) round(x)) + geom_boxplot()
p

ggsave(file="./InteractionForests/Results/Figures/SimulationQuantitative.pdf", width=9, height=10.5)









# Supplementary Figure: EIM values of qualitative interaction effects.
######################################################################

resultsplot <- resultstemp2[resultstemp2$effect %in% c("Strong qual. int.", "Moderate qual. int.", "Weak qual. int."),]
resultsplot$effect[resultsplot$effect=="Strong qual. int."] <- "Strong effect"
resultsplot$effect[resultsplot$effect=="Moderate qual. int."] <- "Moderate effect"
resultsplot$effect[resultsplot$effect=="Weak qual. int."] <- "Weak effect"
resultsplot$effect <- factor(resultsplot$effect, levels=c("Strong effect", "Moderate effect", "Weak effect"))

levels(resultsplot$method) <- c("IF-EIM-qual", "RF-V-pairs", "PA", "IMDMS", "iRF") 

p <- ggplot(data=resultsplot, aes(x=method, y=position)) + theme_bw() + facet_wrap(~ n + effect, scales="free_y", ncol=3) + labs(x="Method", y="Rank") +
  theme(strip.text.x=element_text(size=14), axis.text.x = element_text(angle=45, hjust = 1, color="black", size=13),
        axis.text.y = element_text(size=13), axis.title=element_text(size=15)) + scale_y_continuous(trans='log', breaks=trans_breaks('log', exp), labels = function(x) round(x)) + geom_boxplot()
p

ggsave(file="./InteractionForests/Results/Figures/SimulationQualitative.pdf", width=9, height=10.5)










# Supplementary Figure: Exemplary pairs of variables in a simulated data set (sample size: 500) (for all three effect levels):
##############################################################################################################################

source("./InteractionForests/Functions/Functions_Simulation.R")

set.seed(123)
dataset <- simDataset(N=500, mainstrength=c(3, 2, 1), quantstrength=c(3, 2, 1), qualstrength=c(3, 2, 1))

library("ggpubr")

p1 <- ggplot(data=dataset, aes(x=X51, y=X52, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[1]), y=expression(X[2])) + ggtitle("main effects only")
p2 <- ggplot(data=dataset, aes(x=X57, y=X58, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[7]), y=expression(X[8])) + ggtitle("quantitative interaction effect") 
p3 <- ggplot(data=dataset, aes(x=X63, y=X64, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[13]), y=expression(X[14])) + ggtitle("qualitative interaction effect") 

p123 <- ggarrange(p1, p2, p3, ncol = 3, nrow = 1)
p123 <- annotate_figure(p123, top = text_grob("strong effects", face = "bold", size = 19))

p4 <- ggplot(data=dataset, aes(x=X53, y=X54, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[3]), y=expression(X[4])) + ggtitle("main effects only")
p5 <- ggplot(data=dataset, aes(x=X59, y=X60, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[9]), y=expression(X[10])) + ggtitle("quantitative interaction effect")
p6 <- ggplot(data=dataset, aes(x=X65, y=X66, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[15]), y=expression(X[16])) + ggtitle("qualitative interaction effect") 

p456 <- ggarrange(p4, p5, p6, ncol = 3, nrow = 1)
p456 <- annotate_figure(p456, top = text_grob("moderate effects", face = "bold", size = 19))

p7 <- ggplot(data=dataset, aes(x=X55, y=X56, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[5]), y=expression(X[6])) + ggtitle("main effects only")
p8 <- ggplot(data=dataset, aes(x=X61, y=X62, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[11]), y=expression(X[12])) + ggtitle("quantitative interaction effect")
p9 <- ggplot(data=dataset, aes(x=X67, y=X68, col=y)) + theme_bw() + geom_point() + theme(legend.position = "none", axis.title=element_text(size=15), plot.title = element_text(size=16)) + labs(x=expression(X[17]), y=expression(X[18])) + ggtitle("qualitative interaction effect") 

p789 <- ggarrange(p7, p8, p9, ncol = 3, nrow = 1)
p789 <- annotate_figure(p789, top = text_grob("weak effects", face = "bold", size = 19))

pall <- ggarrange(p123, p456, p789,
                    ncol = 1, nrow = 3)
pall

ggsave(file="./InteractionForests/Results/Figures/SuppSimulationDesign.pdf", width=11, height=13)







# Figure: Exemplary pairs of variables in a simulated data set (sample size: 500) (only strong effets):
#######################################################################################################

titlesize <- 15
axistitlesize <- 20
axistextsize <- 17

p1 <- ggplot(data=dataset, aes(x=X51, y=X52, col=y)) + theme_bw() + geom_point() + 
  theme(legend.position = "none", title=element_text(size=titlesize),
        axis.text=element_text(size=axistextsize),
        axis.title=element_text(size=axistitlesize)) + 
  labs(x=expression(X[1]), y=expression(X[2])) + ggtitle("\nstrong main effects only")
p1
p2 <- ggplot(data=dataset, aes(x=X57, y=X58, col=y)) + theme_bw() + geom_point() + 
  theme(legend.position = "none", title=element_text(size=titlesize),
        axis.text=element_text(size=axistextsize),
        axis.title=element_text(size=axistitlesize)) + 
  labs(x=expression(X[7]), y=expression(X[8])) + ggtitle("strong quantitative\ninteraction effect")
p3 <- ggplot(data=dataset, aes(x=X63, y=X64, col=y)) + theme_bw() + geom_point() + 
  theme(legend.position = "none", title=element_text(size=titlesize),
        axis.text=element_text(size=axistextsize),
        axis.title=element_text(size=axistitlesize)) + 
  labs(x=expression(X[13]), y=expression(X[14])) + ggtitle("strong qualitative\ninteraction effect")

p123 <- ggarrange(p1, p2, p3, ncol = 3, nrow = 1)
p123

ggsave(file="./InteractionForests/Results/Figures/Figure4.pdf", width=12, height=4)
