####################################################################################

# NOTE: Before the code can be executed, the R working directory *MUST* 
# be set to the directory that contains the folder 'InteractionForests' (for Linux
# systems R can also be excecuted from the directory that contains the folder
# 'InteractionForests'):

# Remove '#' from the line below and replace 'Z:/here/is/my/path/' by the path
# to the directory that contains 'InteractionForests':

# setwd("Z:/here/is/my/path/")

####################################################################################



# 'stock' data set:
###################


load("./InteractionForests/Data/ExampleDatasets/datastock.Rda")


library("diversityForest")

set.seed(1234)
model <- interactionfor(dependent.variable.name = "company10", data = datastock, 
                        importance="both")



# univariable EIM values sorted in descending order:

model$eim.univ.sorted



# plot.interactionfor():

myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    require("scales")
    
    ps <- list()
    count <- 1
    
    if (!is.null(intobj$eim.univ)) {
      datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
      ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
        labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.quant)) {
      datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
      ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.qual)) {
      datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
      ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    
    p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    return(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
    # 
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/stockEIM.pdf", width=7, height=9)




myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    if (!is.null(intobj$eim.quant)) {
      ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }

    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)

set.seed(1234)
p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/stockTopQuant.pdf", width=12, height=11)




myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     return(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       return(p)
    #     }
    #   }
    # }
    
    if (!is.null(intobj$eim.qual)) {
      ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


set.seed(1234)
p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/stockTopQual.pdf", width=12, height=11)






# plotEffects(): 

set.seed(1234)
ps <- plotEffects(model, allwith="company7", type="qual", numpairs=8, plotit=FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/stockTopQual7_1.pdf", width=12, height=11)


ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/stockTopQual7_2.pdf", width=12, height=11)


ps[[4]]

ggsave(file="./InteractionForests/Results/Figures/stockTopQual7_3.pdf", width=12, height=11)




# Figure 2: Example of plot produced by the diversityForest R package to visualise
# the estimated bivariable influence of a variable pair.

set.seed(1234)
ps <- plotEffects(model, type="qual", numpairs=1, plotit=FALSE, addtitles=FALSE)

ps[[1]]

ggsave(file="./InteractionForests/Results/Figures/Figure2.pdf", width=14, height=5.6)






# 'zoo' data set:
###################


load("./InteractionForests/Data/ExampleDatasets/datazoo.Rda")

set.seed(1234)
model <- interactionfor(dependent.variable.name = "type", data = datazoo)



# univariable EIM values sorted in descending order:

model$eim.univ.sorted




# plot.interactionfor():

myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    require("scales")
    
    ps <- list()
    count <- 1
    
    if (!is.null(intobj$eim.univ)) {
      datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
      ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
        labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.quant)) {
      datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
      ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.qual)) {
      datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
      ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    
    p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    return(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
    # 
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/zooEIM.pdf", width=7, height=9)




myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    if (!is.null(intobj$eim.quant)) {
      ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
    
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/zooTopQuant.pdf", width=12, height=11)




myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     return(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       return(p)
    #     }
    #   }
    # }
    
    if (!is.null(intobj$eim.qual)) {
      ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/zooTopQual.pdf", width=12, height=11)





# plotEffects(): 

ps <- plotEffects(model, type="qual", plotit=FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/zooTopQual7_1.pdf", width=12, height=11)

ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/zooTopQual7_2.pdf", width=12, height=6)





# plotPair(): Estimated bivariable influence of the variable pair 
# toothed and feathers:

p <- plotPair(pair=c("toothed", "feathers"), yvarname="type", data=datazoo)

ggsave(file="./InteractionForests/Results/Figures/zooToothedFeathers.pdf", width=12, height=6)





# Further results described in Section C.2 of the Supplement:


hair_backbone <- paste(datazoo$hair, datazoo$backbone, sep="_")
table(hair_backbone, datazoo$type)

datazoowanimal$animal[hair_backbone=="false_true" & datazoo$type=="mammal"]
datazoowanimal$animal[hair_backbone=="true_false"]



eggs_venomous <- paste(datazoo$eggs, datazoo$venomous, sep="_")
table(eggs_venomous, datazoo$type)
datazoowanimal$animal[eggs_venomous=="true_false" & datazoo$type=="mammal"]




datazoowanimal$animal[datazoo$tail=="true" & datazoo$legs==2]
datazoowanimal$animal[datazoo$tail=="true" & datazoo$legs==4]

datazoowanimal$animal[datazoo$tail=="false" & datazoo$legs==2]
datazoowanimal$animal[datazoo$tail=="false" & datazoo$legs==4]




datazoowanimal$animal[datazoo$fins=="true" & datazoo$tail=="false" & datazoo$type=="mammal"]
datazoowanimal$animal[datazoo$fins=="true" & datazoo$tail=="false" & datazoo$type=="other"]

datazoowanimal$animal[datazoo$fins=="true" & datazoo$tail=="true" & datazoo$type=="mammal"]
datazoowanimal$animal[datazoo$fins=="true" & datazoo$tail=="true" & datazoo$type=="other"]




datazoowanimal$animal[datazoo$feathers=="true"]

datazoowanimal$animal[datazoo$feathers=="false" & datazoo$toothed=="false" & datazoo$type=="mammal"]
datazoowanimal$animal[datazoo$feathers=="false" & datazoo$toothed=="false" & datazoo$type=="other"]

datazoowanimal$animal[datazoo$feathers=="true" & datazoo$toothed=="false" & datazoo$type=="mammal"]
datazoowanimal$animal[datazoo$feathers=="true" & datazoo$toothed=="false" & datazoo$type=="other"]

datazoowanimal$animal[datazoo$feathers=="false" & datazoo$toothed=="true" & datazoo$type=="mammal"]
datazoowanimal$animal[datazoo$feathers=="false" & datazoo$toothed=="true" & datazoo$type=="other"]









# 'white-clover' data set:
##########################


load("./InteractionForests/Data/ExampleDatasets/dataclover.Rda")



set.seed(1234)
model <- interactionfor(dependent.variable.name = "amount", data = dataclover)




# plot.interactionfor():

myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    require("scales")
    
    ps <- list()
    count <- 1
    
    if (!is.null(intobj$eim.univ)) {
      datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
      ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
        labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.quant)) {
      datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
      ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.qual)) {
      datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
      ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    
    p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    return(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
    # 
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/cloverEIM.pdf", width=7, height=9)




myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    if (!is.null(intobj$eim.quant)) {
      ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
    
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/cloverTopQuant.pdf", width=12, height=11)




myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     return(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       return(p)
    #     }
    #   }
    # }
    
    if (!is.null(intobj$eim.qual)) {
      ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)


p <- myplotinteractionfor(model)
p

ggsave(file="./InteractionForests/Results/Figures/cloverTopQual.pdf", width=12, height=11)





# plotEffects(): 

ps <- plotEffects(model, plotit = FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/cloverTopQuant_1.pdf", width=12, height=11)

ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/cloverTopQuant_2.pdf", width=12, height=6)



ps <- plotEffects(model, type="qual", plotit = FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/cloverTopQual_1.pdf", width=12, height=11)

ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/cloverTopQual_2.pdf", width=12, height=6)









# 'colon-rna' data set, survival outcome:
#########################################


load("./InteractionForests/Data/ExampleDatasets/COAD_rna_mutation_targetvar.Rda")

datarnasurv <- data.frame(rna)
datarnasurv$time <- targetvar$time
datarnasurv$status <- targetvar$status


set.seed(1234)
modelsurv <- interactionfor(dependent.variable.name = "time", 
                            status.variable.name = "status", data = datarnasurv)




# plot.interactionfor():

myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    require("scales")
    
    ps <- list()
    count <- 1
    
    if (!is.null(intobj$eim.univ)) {
      datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
      ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
        labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.quant)) {
      datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
      ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.qual)) {
      datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
      ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    
    p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    return(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
    # 
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)

set.seed(1234)
p <- myplotinteractionfor(modelsurv)
p

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvEIM.png", width=7, height=9)




myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    if (!is.null(intobj$eim.quant)) {
      ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
    
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)

set.seed(1234)
p <- myplotinteractionfor(modelsurv)
p

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvTopQuant.pdf", width=12, height=11)





myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     return(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       return(p)
    #     }
    #   }
    # }
    
    if (!is.null(intobj$eim.qual)) {
      ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)

set.seed(1234)
p <- myplotinteractionfor(modelsurv)
p

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvTopQual.pdf", width=12.7, height=12.7)





# plotEffects(): 

set.seed(1234)
ps <- plotEffects(modelsurv, plotit = FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvTopQuant_1.pdf", width=12, height=11)

ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvTopQuant_2.pdf", width=12, height=6)




set.seed(1234)
ps <- plotEffects(modelsurv, type="qual", plotit = FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvTopQual_1.pdf", width=12, height=11)

ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvTopQual_2.pdf", width=12, height=6)



set.seed(1234)
ps <- plotEffects(modelsurv, indpairs=c(100, 2500), plotit = FALSE)

ps[[1]]

ggsave(file="./InteractionForests/Results/Figures/colonrnasurvLowQuant.pdf", width=12.7, height=12.7)







# 'colon-rna' data set, binary outcome 'TP53':
##############################################

datatp53 <- data.frame(rna)
datatp53$TP53 <- factor(mutation[,"TP53"])
levels(datatp53$TP53) <- c("No", "Yes")
datatp53$TP53 <- factor(as.character(datatp53$TP53), levels=c("Yes", "No"))



set.seed(1234)
modeltp53 <- interactionfor(dependent.variable.name = "TP53", data = datatp53)





# plot.interactionfor():

myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    require("scales")
    
    ps <- list()
    count <- 1
    
    if (!is.null(intobj$eim.univ)) {
      datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
      ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
        labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.quant)) {
      datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
      ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    if (!is.null(intobj$eim.qual)) {
      datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
      ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
        labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects") +
        scale_x_continuous(breaks= pretty_breaks())
      count <- count+1
    }
    
    p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    return(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
    # 
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)

set.seed(1234)
p <- myplotinteractionfor(modeltp53)
p

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53EIM.png", width=7, height=9)





myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    if (!is.null(intobj$eim.quant)) {
      ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
    
    # if (!is.null(intobj$eim.qual)) {
    #   ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
    #     print(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       print(p)
    #     }
    #   }
    # }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)

set.seed(1234)
p <- myplotinteractionfor(modeltp53)
p

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53TopQuant.pdf", width=12, height=11)





myplotinteractionfor <- function(intobj, numpairsquant=2, numpairsqual=2) {
  
  if(is.null(intobj$eim.univ) & is.null(intobj$eim.quant) & is.null(intobj$eim.qual)) {
    cat("Nothing to plot, because the 'interactionfor' object does not feature EIM values.", "\n")
  } else {
    
    require("ggplot2")
    require("ggpubr")
    
    # ps <- list()
    # count <- 1
    # 
    # if (!is.null(intobj$eim.univ)) {
    #   datatempuniv <- data.frame(eimuniv=intobj$eim.univ.sorted)
    #   ps[[count]] <- ggplot(data=datatempuniv, aes(x=1:nrow(datatempuniv), y=eimuniv)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable", y="univariable EIM values") + ggtitle("univariable effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.quant)) {
    #   datatempquant <- data.frame(eimquant=intobj$eim.quant.sorted)
    #   ps[[count]] <- ggplot(data=datatempquant, aes(x=1:nrow(datatempquant), y=eimquant)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="quantitative EIM values") + ggtitle("quantitative interaction effects")
    #   count <- count+1
    # }
    # if (!is.null(intobj$eim.qual)) {
    #   datatempqual <- data.frame(eimqual=intobj$eim.qual.sorted)
    #   ps[[count]] <- ggplot(data=datatempqual, aes(x=1:nrow(datatempqual), y=eimqual)) + theme_bw() + geom_point() + 
    #     labs(x="Index of variable pair", y="qualitative EIM values") + ggtitle("qualitative interaction effects")
    #   count <- count+1
    # }
    # 
    # p <- ggarrange(plotlist=ps, nrow=length(ps), ncol = 1)
    # p <- annotate_figure(p, top = text_grob(ifelse(length(ps)==1, "Distribution of EIM values", "Distributions of EIM values"), face = "bold", size = 18))
    # print(p)
    
    # if (!is.null(intobj$eim.quant)) {
    #   ps <- plotEffects(intobj=intobj, type="quant", numpairs=numpairsquant, plotit=FALSE)
    #   if(length(ps)==1) {
    #     readline(prompt="Press [enter] for next plot.")
    #     p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top quantitative EIM values", face = "bold", size = 18))
    #     return(p)
    #   } else {
    #     for(i in seq(along=ps)) {
    #       readline(prompt="Press [enter] for next plot.")
    #       p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top quantitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
    #       return(p)
    #     }
    #   }
    # }
    
    if (!is.null(intobj$eim.qual)) {
      ps <- plotEffects(intobj=intobj, type="qual", numpairs=numpairsqual, plotit=FALSE)
      if(length(ps)==1) {
        readline(prompt="Press [enter] for next plot.")
        p <- annotate_figure(ps[[1]], top = text_grob("Pairs with top qualitative EIM values", face = "bold", size = 18))
        return(p)
      } else {
        for(i in seq(along=ps)) {
          readline(prompt="Press [enter] for next plot.")
          p <- annotate_figure(ps[[i]], top = text_grob(paste("Pairs with top qualitative EIM values - ", as.roman(i), sep=""), face = "bold", size = 18))
          return(p)
        }
      }
    }
  }
  
}

environment(myplotinteractionfor) <- environment(interactionfor)

set.seed(1234)
p <- myplotinteractionfor(modeltp53)
p

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53TopQual.pdf", width=12, height=11)






# Largest univariable EIM values:

head(modeltp53$eim.univ.sorted)





# Further results described in Section C.4 of the Supplement:


# ENSG00000174307 was featured the second most frequently in the pre-selected variable
# pairs (63 times) and ENSG00000087088 the fourth most frequently (36 times):

tabinpairs <- table(unlist(lapply(modeltp53$promispairs, function(x) names(datatp53)[x])))
tabinpairs <- sort(tabinpairs, decreasing = TRUE)
head(tabinpairs)


# Compute the classical permutation variable importance values of 
# conventional random forests:

set.seed(1234)
require("ranger")
modeltp53ranger <- ranger(dependent.variable.name = "TP53", data = datatp53, num.trees=20000, importance="permutation")


# ENSG00000174307 has the 27th largest permutation VIM value among all variables

which(names(sort(modeltp53ranger$variable.importance, decreasing=TRUE))=="ENSG00000174307")

# ENSG00000087088 has the 11th largest permutation VIM value:

which(names(sort(modeltp53ranger$variable.importance, decreasing=TRUE))=="ENSG00000087088")

# ENSG00000135679, that had the third largest univariable EIM value has the second
# largest permutation VIM value:

which(names(sort(modeltp53ranger$variable.importance, decreasing=TRUE))=="ENSG00000135679")


# Three of the ten variables with largest permutation VIM values were not featured
# in the pre-selected  pairs and thus received an univariable EIM value of zero:

sum(sapply(names(sort(modeltp53ranger$variable.importance, decreasing=TRUE))[1:10], function(x) !(x %in% names(tabinpairs))))







# plotEffects():


set.seed(1234)
ps <- plotEffects(modeltp53, plotit = FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53TopQuant_1.pdf", width=12, height=11)

ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53TopQuant_2.pdf", width=12, height=6)




set.seed(1234)
ps <- plotEffects(modeltp53, type="qual", plotit = FALSE)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53TopQual_1.pdf", width=12, height=11)

ps[[3]]

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53TopQual_2.pdf", width=12, height=6)




set.seed(1234)
ps <- plotEffects(modeltp53, type="qual", indpairs=c(7,9,10,11), plotit=FALSE)

ps[[1]]

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53LowerQual_1.pdf", width=12, height=11)

ps[[2]]

ggsave(file="./InteractionForests/Results/Figures/colonrnatp53LowerQual_2.pdf", width=12, height=11)
