# Set working directory:

setwd("~/")



# Make table of settings:

dataids <- c("37", "334", "914", "915", "919", "921", "924", "925", "927", "928", "929", 
             "931", "335", "934", "945", "946", "947", "949", "950", "951", "955", "962", 
             "964", "336", "965", "969", "973", "974", "983", "987", "988", "991", "994", 
             "997", "337", "1005", "1009", "1011", "1013", "1014", "1015", "1016", "1025", 
             "1045", "1048", "346", "1054", "1055", "1059", "1060", "1061", "1062", "1063", 
             "1064", "1065", "1066", "444", "1071", "1073", "1075", "1121", "1441", "1442", 
             "1446", "1447", "1455", "1462", "446", "1463", "1464", "1467", "1473", "1480", 
             "1488", "1490", "1495", "1498", "1510", "448", "1511", "1524", "31", "311", 
             "720", "725", "728", "737", "803", "450", "807", "816", "819", "847", "851", 
             "923", "954", "958", "970", "995", "459", "1021", "1049", "1050", "1067", "1068", 
             "1443", "1444", "1451", "1452", "40", "467", "1453", "1454", "1489", "1494", 
             "1504", "1547", "1570", "44", "312", "472", "316", "735", "761", "476", "971", 
             "976", "978", "980", "1020", "1022", "1042", "479", "1043", "1056", "1069", 
             "1479", "1487", "682", "1038", "1039", "1176", "683", "713", "714", "717", 
             "719", "43", "721", "724", "729", "731", "733", "736", "741", "745", "747", 
             "748", "50", "750", "753", "755", "758", "759", "764", "765", "767", "770", 
             "771", "53", "772", "774", "777", "778", "780", "782", "784", "787", "788", 
             "790", "59", "791", "795", "800", "801", "804", "811", "814", "815", "817", 
             "818", "164", "820", "826", "827", "835", "841", "848", "853", "857", "859", 
             "860", "292", "872", "874", "875", "880", "882", "885", "886", "887", "890", 
             "892", "333", "893", "894", "895", "900", "902", "905", "906", "907", "908", 
             "909")


method <- c("randomforest", "interactionforest", "rotationforest", "obliqueforest", "canonicalforest")

cvind <- 1:5

scenariogrid <- expand.grid(method=method, cvind=cvind, 
  dataid=dataids, stringsAsFactors = FALSE)
scenariogrid <- scenariogrid[,ncol(scenariogrid):1, drop=FALSE]


set.seed(1234)
seeds <- sample(1000:10000000, size=length(dataids)*length(cvind))

scenariogrid$seed <- rep(seeds, each=length(method))


set.seed(1234)
reorderind <- sample(1:nrow(scenariogrid))
scenariogrid <- scenariogrid[reorderind,,drop=FALSE]
rownames(scenariogrid) <- NULL


scenariogrid <- scenariogrid[!(scenariogrid$dataid %in% c("1042", "1038", "1039", "1176")),]


scenariogrid$settingid <- 1:nrow(scenariogrid)
rownames(scenariogrid) <- 1:nrow(scenariogrid)




# Save scenariogrid, needed in evaluation of the results:

save(scenariogrid, file="./InteractionForests/Results/scenariogrid_LargeStudy.Rda")




# Source the functions that are used in performing the calculations 
# on the cluster:

source("./InteractionForests/Functions/Functions_LargeStudy.R")



# Consider only settings that do NOT use the Oblique Forest (these
# calculations are more demanding and have to be performed on a
# cluster with more memory):

scenariogrid <- scenariogrid[scenariogrid$method!="obliqueforest",]



# Start the cluster:

# NOTE: This syntax requires the use of the RMPISNOW script, see the README file
# contained in the root folder "InteractionForests".

cl <- makeCluster()



# Export the objects in the workspace to the
# parallel jobs:

clusterExport(cl, list=ls())



# Perform the calculations and save the results (saving is performed within 'evaluatesetting'):

Results <- parLapply(cl, 1:nrow(scenariogrid), function(z)
  try({evaluatesetting(z)}))

  
  
# Stop the cluster:

stopCluster(cl)
