# Set working directory:

setwd("~/")



# Make table of settings:

n <- c(100, 500, 1000)
itind <- 1:200

scenariogrid <- expand.grid(itind=itind, 
                            n=n, stringsAsFactors = FALSE)
scenariogrid <- scenariogrid[,ncol(scenariogrid):1, drop=FALSE]


set.seed(1234)
seeds <- sample(1000:10000000, size=length(n)*length(itind))

scenariogrid$seed <- rep(seeds, each=1)


set.seed(1234)
reorderind <- sample(1:nrow(scenariogrid))
scenariogrid <- scenariogrid[reorderind,,drop=FALSE]
rownames(scenariogrid) <- NULL

scenariogrid$settingid <- 1:nrow(scenariogrid)
rownames(scenariogrid) <- 1:nrow(scenariogrid)





# Subset scenariogrid to feature only settings with n = 100:

scenariogrid <- scenariogrid[which(scenariogrid$n==100),]




# Save scenariogrid, needed in evaluation of the results:

save(scenariogrid, file="./InteractionForests/Results/scenariogrid_Simulation_100.Rda")




# Source the functions that are used in performing the calculations 
# on the cluster:

source("./InteractionForests/Functions/Functions_Simulation.R")




# Start the cluster:

# NOTE: This syntax requires the use of the RMPISNOW script, see the README file
# contained in the root folder "InteractionForests".

cl <- makeCluster()



# Export the objects in the workspace to the
# parallel jobs:

clusterExport(cl, list=ls())



# Perform the calculations:

Results <- parLapply(cl, 1:nrow(scenariogrid), function(z)
  try({evaluatesetting(z)}))

  
  
# Save the results:

save(Results, file="./InteractionForests/Results/Results_Simulation_100.Rda")


  
# Stop the cluster:

stopCluster(cl)
