# Set working directory:

setwd("~/")



# Make table of settings:

n <- c(100, 500, 1000)
itind <- 1:200

scenariogrid <- expand.grid(itind=itind, 
                            n=n, stringsAsFactors = FALSE)
scenariogrid <- scenariogrid[,ncol(scenariogrid):1, drop=FALSE]


set.seed(1234)
seeds <- sample(1000:10000000, size=length(n)*length(itind))

scenariogrid$seed <- rep(seeds, each=1)


set.seed(1234)
reorderind <- sample(1:nrow(scenariogrid))
scenariogrid <- scenariogrid[reorderind,,drop=FALSE]
rownames(scenariogrid) <- NULL

scenariogrid$settingid <- 1:nrow(scenariogrid)
rownames(scenariogrid) <- 1:nrow(scenariogrid)




# Subset scenariogrid to feature only setting with n = 1000:

scenariogrid <- scenariogrid[which(scenariogrid$n==1000),]




# Save scenariogrid, needed in evaluation of the results:

save(scenariogrid, file="./InteractionForests/Results/scenariogrid_Simulation_1000.Rda")




# Source the functions that are used in performing the calculations 
# on the cluster:

source("./InteractionForests/Functions/Functions_Simulation.R")





# Load 'parallel'-package: 

library("parallel") 



# Specify the random seed generator to be used:

RNGkind("L'Ecuyer-CMRG")



# Set the seed for repoducability:

set.seed(1234)



# Perform the calculations:

Results <- mclapply(1:nrow(scenariogrid), function(z) try({evaluatesettingn1000(z)}), mc.silent=TRUE, mc.cores = 30) 


  
# Save the results:

save(Results, file="./InteractionForests/Results/Results_Simulation_1000.Rda")
