# For details on the simulation design and its setup see Supplementary File 1,
# section "E.3 Detailed description of the simulation setting". This will help
# to understand the current script.


# In this script we show how the simulation parameters for the simulation of the
# quantitative and qualitative interactions were determined.



###############################################################################
# Determine mean overlapping indices strong, moderately strong, and weak variables
# have with other variables:
###############################################################################


# Determine mean overlapping index strong variables have with other variables:


# Overlap with other strong variable:

d <- 1

eps <- 0

library("mvtnorm")

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 1+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,1))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexstrong <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexstrong

round(oindexstrong, 3)



# Overlap with moderately strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.75+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.75))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexmiddle <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexmiddle

round(oindexmiddle, 3)



# Overlap with weak variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.5+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.5))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexweak <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexweak

round(oindexweak, 3)



# Overlap with non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)




# Increase the ranges in the numerical calculations, in order to check whether the chosen range
# was large enough:

eps <- 2



# Overlap with other strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 1+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,1))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexstrong <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexstrong

round(oindexstrong, 3)




# Overlap with moderately strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.75+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.75))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexmiddle <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexmiddle

round(oindexmiddle, 3)




# Overlap with weak variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.5+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.5))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexweak <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexweak

round(oindexweak, 3)



# Overlap with non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)



# --> Results were the same as for the other grid.





# Calculate the mean overlapping index strong variables have with other variables:

oindexstrong <- 0.48
oindexmiddle <- 0.532
oindexweak <- 0.576
oindexno <- 0.617

oindexmeandlarge <- (50*oindexno + 1*oindexstrong + 2*oindexmiddle + 2*oindexweak)/55

oindexmeandlarge

round(oindexmeandlarge, 3)

oindexmeandlarge <- 0.610









# Determine mean overlapping index moderately strong variables have with other variables:


d <- 0.75

# Overlap with strong variable:

eps <- 0


xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 1+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,1))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexstrong <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexstrong

round(oindexstrong, 3)




# Overlap with other moderately strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.75+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.75))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexmiddle <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexmiddle

round(oindexmiddle, 3)




# Overlap with weak variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.5+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.5))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexweak <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexweak

round(oindexweak, 3)





# Overlap with non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)






# Increase the ranges in the numerical calculations, in order to check whether the chosen range
# was large enough:

eps <- 2


# Overlap with strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 1+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,1))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexstrong <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexstrong

round(oindexstrong, 3)




# Overlap with other moderately strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.75+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.75))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexmiddle <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexmiddle

round(oindexmiddle, 3)





# Overlap with weak variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.5+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.5))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexweak <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexweak

round(oindexweak, 3)





# Overlap with non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)


# --> The latter result differed slightly from the
# result obtained for the other range, increase the resolution:


# Overlap with non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=200)
ygrid <- seq(-4-eps, 0+4+eps, length=200)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)

# --> Result is the same as the one further above. -> Use that result.





# Calculate the mean overlapping index moderately strong variables have with other variables:

oindexstrong <- 0.532
oindexmiddle <- 0.596
oindexweak <- 0.652
oindexno <- 0.708

oindexmeandmedium <- (50*oindexno + 2*oindexstrong + 1*oindexmiddle + 2*oindexweak)/55

oindexmeandmedium

round(oindexmeandmedium, 3)

oindexmeandmedium <- 0.698











# Determine mean overlapping index weak variables have with other variables:

d <- 0.5

# Overlap with strong variable:

eps <- 0

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 1+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,1))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexstrong <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexstrong

round(oindexstrong, 3)



# Overlap with moderately strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.75+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.75))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexmiddle <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexmiddle

round(oindexmiddle, 3)




# Overlap with other weak variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.5+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.5))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexweak <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexweak

round(oindexweak, 3)




# Overlap with non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)





# Increase the ranges in the numerical calculations, in order to check whether the chosen range
# was large enough:


eps <- 2


# Overlap with strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 1+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,1))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexstrong <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexstrong

round(oindexstrong, 3)



# Overlap with moderately strong variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.75+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.75))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexmiddle <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexmiddle

round(oindexmiddle, 3)





# Overlap with other weak variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0.5+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0.5))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexweak <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexweak

round(oindexweak, 3)





# Overlap with non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=100)
ygrid <- seq(-4-eps, 0+4+eps, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)


# --> The latter result differed slightly from the
# result obtained for the other range, increase the resolution:


# For non-informative variable:

# For non-informative variable:

xgrid <- seq(-4-eps, d+4+eps, length=200)
ygrid <- seq(-4-eps, 0+4+eps, length=200)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) dmvnorm(x=x, mean=c(0,0))
class2d <- function(x) dmvnorm(x=x, mean=c(d,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindexno <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindexno

round(oindexno, 3)





# Calculate the mean overlapping index weak variables have with other variables:

oindexstrong <- 0.576
oindexmiddle <- 0.652
oindexweak <- 0.724
oindexno <- 0.803

oindexmeandweak <- (50*oindexno + 2*oindexstrong + 2*oindexmiddle + 1*oindexweak)/55

oindexmeandweak

round(oindexmeandweak, 3)

oindexmeandweak <- 0.788





# Mean overlapping indices strong, moderately strong, and weak variables have with
# other variables (calculated above):

oindexmeandlarge <- 0.610
oindexmeandmedium <- 0.698
oindexmeandweak <- 0.788












###############################################################################
# Determine the widths of the rectangles for quantitative and qualitative interactions
# in such way that their overlapping indices are equal to the mean overlapping indices
# for strong, moderately strong, and weak variables calculated above (equal up to 
# three decimal points)
###############################################################################



# The following values for the widths were all determined by trial and error:



# Qualitative interactions:



# Strong influence:



dquallarge <- 1.772

xgrid <- seq(-4, dquallarge+4, length=100)
ygrid <- seq(-4, dquallarge+4, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/2)*dmvnorm(x=x, mean=c(0,0)) + (1/2)*dmvnorm(x=x, mean=c(dquallarge,dquallarge))
class2d <- function(x) (1/2)*dmvnorm(x=x, mean=c(dquallarge,0)) + (1/2)*dmvnorm(x=x, mean=c(0,dquallarge))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)




# Expand ranges and see whether the same result is obtained:

xgrid <- seq(-4-2, dquallarge+4+2, length=100)
ygrid <- seq(-4-2, dquallarge+4+2, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/2)*dmvnorm(x=x, mean=c(0,0)) + (1/2)*dmvnorm(x=x, mean=c(dquallarge,dquallarge))
class2d <- function(x) (1/2)*dmvnorm(x=x, mean=c(dquallarge,0)) + (1/2)*dmvnorm(x=x, mean=c(0,dquallarge))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)

# --> Same result.






# Moderately strong influence:


dqualmedium <- 1.51


xgrid <- seq(-4, dqualmedium+4, length=100)
ygrid <- seq(-4, dqualmedium+4, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/2)*dmvnorm(x=x, mean=c(0,0)) + (1/2)*dmvnorm(x=x, mean=c(dqualmedium,dqualmedium))
class2d <- function(x) (1/2)*dmvnorm(x=x, mean=c(dqualmedium,0)) + (1/2)*dmvnorm(x=x, mean=c(0,dqualmedium))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)




# Expand ranges and see whether the same result is obtained:

xgrid <- seq(-4-2, dqualmedium+4+2, length=100)
ygrid <- seq(-4-2, dqualmedium+4+2, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/2)*dmvnorm(x=x, mean=c(0,0)) + (1/2)*dmvnorm(x=x, mean=c(dqualmedium,dqualmedium))
class2d <- function(x) (1/2)*dmvnorm(x=x, mean=c(dqualmedium,0)) + (1/2)*dmvnorm(x=x, mean=c(0,dqualmedium))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)

# --> (Slightly) different result.




# Increase resolution of the grid from 100 to 200 to see whether this changes 
# the above result:

xgrid <- seq(-4-2, dqualmedium+4+2, length=200)
ygrid <- seq(-4-2, dqualmedium+4+2, length=200)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/2)*dmvnorm(x=x, mean=c(0,0)) + (1/2)*dmvnorm(x=x, mean=c(dqualmedium,dqualmedium))
class2d <- function(x) (1/2)*dmvnorm(x=x, mean=c(dqualmedium,0)) + (1/2)*dmvnorm(x=x, mean=c(0,dqualmedium))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)

# --> OK.







# Weak influence:


dqualweak <- 1.225



xgrid <- seq(-4, dqualweak+4, length=100)
ygrid <- seq(-4, dqualweak+4, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/2)*dmvnorm(x=x, mean=c(0,0)) + (1/2)*dmvnorm(x=x, mean=c(dqualweak,dqualweak))
class2d <- function(x) (1/2)*dmvnorm(x=x, mean=c(dqualweak,0)) + (1/2)*dmvnorm(x=x, mean=c(0,dqualweak))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)




# Expand ranges and see whether the same result is obtained:

xgrid <- seq(-4-2, dqualweak+4+2, length=100)
ygrid <- seq(-4-2, dqualweak+4+2, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/2)*dmvnorm(x=x, mean=c(0,0)) + (1/2)*dmvnorm(x=x, mean=c(dqualweak,dqualweak))
class2d <- function(x) (1/2)*dmvnorm(x=x, mean=c(dqualweak,0)) + (1/2)*dmvnorm(x=x, mean=c(0,dqualweak))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)

# --> Same result.












# Quantitative interactions:



# Strong influence:


dqual <- 1.772
dquant <- dqual


propcorner <- 0.649



xgrid <- seq(-4, dquant+4, length=100)
ygrid <- seq(-4, dquant+4, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + (1/3)*dmvnorm(x=x, mean=c(0,0)) + 
  (1/3)*dmvnorm(x=x, mean=c(dquant,0))
class2d <- function(x) propcorner*dmvnorm(x=x, mean=c(0,dquant)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + 
  ((1-propcorner)/3)*dmvnorm(x=x, mean=c(0,0)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)




# Expand ranges and see whether the same result is obtained:

xgrid <- seq(-4-2, dquant+4+2, length=100)
ygrid <- seq(-4-2, dquant+4+2, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + (1/3)*dmvnorm(x=x, mean=c(0,0)) + 
  (1/3)*dmvnorm(x=x, mean=c(dquant,0))
class2d <- function(x) propcorner*dmvnorm(x=x, mean=c(0,dquant)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + 
  ((1-propcorner)/3)*dmvnorm(x=x, mean=c(0,0)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))

oindex

round(oindex, 3)

# --> Same result.








# Moderately strong influence:


dqual <- 1.51
dquant <- dqual

propcorner <- 0.574




xgrid <- seq(-4, dquant+4, length=100)
ygrid <- seq(-4, dquant+4, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + (1/3)*dmvnorm(x=x, mean=c(0,0)) + 
  (1/3)*dmvnorm(x=x, mean=c(dquant,0))
class2d <- function(x) propcorner*dmvnorm(x=x, mean=c(0,dquant)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + 
  ((1-propcorner)/3)*dmvnorm(x=x, mean=c(0,0)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))


oindex

round(oindex, 3)




# Expand ranges and see whether the same result is obtained:

xgrid <- seq(-4-2, dquant+4+2, length=100)
ygrid <- seq(-4-2, dquant+4+2, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + (1/3)*dmvnorm(x=x, mean=c(0,0)) + 
  (1/3)*dmvnorm(x=x, mean=c(dquant,0))
class2d <- function(x) propcorner*dmvnorm(x=x, mean=c(0,dquant)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + 
  ((1-propcorner)/3)*dmvnorm(x=x, mean=c(0,0)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))


oindex

round(oindex, 3)

# --> Same result.








# Weak influence:


dqual <- 1.225
dquant <- dqual


propcorner <- 0.485



xgrid <- seq(-4, dquant+4, length=100)
ygrid <- seq(-4, dquant+4, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + (1/3)*dmvnorm(x=x, mean=c(0,0)) + 
  (1/3)*dmvnorm(x=x, mean=c(dquant,0))
class2d <- function(x) propcorner*dmvnorm(x=x, mean=c(0,dquant)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + 
  ((1-propcorner)/3)*dmvnorm(x=x, mean=c(0,0)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))


oindex

round(oindex, 3)




# Expand ranges and see whether the same result is obtained:

xgrid <- seq(-4-2, dquant+4+2, length=100)
ygrid <- seq(-4-2, dquant+4+2, length=100)

xygrid <- expand.grid(y=ygrid, x=xgrid)[,2:1]

class1d <- function(x) (1/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + (1/3)*dmvnorm(x=x, mean=c(0,0)) + 
  (1/3)*dmvnorm(x=x, mean=c(dquant,0))
class2d <- function(x) propcorner*dmvnorm(x=x, mean=c(0,dquant)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,dquant)) + 
  ((1-propcorner)/3)*dmvnorm(x=x, mean=c(0,0)) + ((1-propcorner)/3)*dmvnorm(x=x, mean=c(dquant,0))

class1norm <- sum(apply(xygrid, 1, class1d))
class2norm <- sum(apply(xygrid, 1, class2d))

class1dnorm <- function(x) class1d(x)/class1norm
class2dnorm <- function(x) class2d(x)/class2norm

oindex <- sum(apply(xygrid, 1, function(x) min(class1dnorm(x), class2dnorm(x))))


oindex

round(oindex, 3)

# --> Same result.




# --> The parameters determined in this script are used in the functions for simulating
# the data in script "Functions/Functions_Simulation.R".
